//
// AutoPrefCheckBox.h - simple classes to link preferences to dialog controls.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_AutoPrefCheckBox_h
#define vgui_AutoPrefCheckBox_h

#include "IAutoPref.h"

#include "String.h"
#include "CheckBox.h"

namespace vgui
{
	/**************************************************************************
	
	>	class AutoPrefCheckBox : public IAutoPref
	
		Author:		Tim Browse
		Date:		10/5/2002
	
		Purpose:	Provide an AutoPref for boolean preferences, linked to
					a standard checkbox.
	
	**************************************************************************/
	
	class AutoPrefCheckBox : public IAutoPref
	{
		public:
			// Ctor
			AutoPrefCheckBox();

			// Attach the AutoPref to the specified checkbox, using the
			// specified preference name
			void Attach(Dialog* pDialog,
						ControlID CheckBoxID,
						const vos::String& PrefName,
						bool bDefaultValue = true);

			virtual void CommitPreference();

			// Mimic the CheckBox interface
			AutoPrefCheckBox& operator=(bool NewState);
			AutoPrefCheckBox& operator=(ControlState NewState);

			operator bool();

			bool GetState() const;
			ControlState GetTriState() const;

			// Allows a checkbox to fade/unfade one or more controls automatically
			void EnableLinkedControls(Dialog* pParentDialog);
			void AddLinkedControl(ControlID ID);
			void AddLinkedControls(const ControlID* pIDs);

		private:
			// Checkbox object to attach to the dialog control
			vgui::CheckBox m_CheckBox;

			// Name of preference to link to
			vos::String m_PrefName;
	};
};

#endif // !vgui_AutoPrefCheckBox_h
