//
// AutoPrefDropDownList.h - simple classes to link preferences to dialog controls.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_AutoPrefDropDownList_h
#define vgui_AutoPrefDropDownList_h

#include "IAutoPref.h"

#include "String.h"
#include "DropDownList.h"

namespace vgui
{
	/**************************************************************************

	>	class AutoPrefDropDownList : public DropDownList, 
									 public IAutoPref


		Author:		Tim Browse
		Date:		8/6/2002

		Purpose:	Provide an auto-pref object to store/restore the contents
					of a DropDownList control.

	**************************************************************************/

	class AutoPrefDropDownList : public DropDownList, 
								 public IAutoPref
	{
		public:
			// We have to reimplement the assignment operators - they're
			// not inherited from the base class.
			AutoPrefDropDownList& operator=(const String& ItemName);
			AutoPrefDropDownList& operator=(const StringResourceID& ItemName);

			// Attach the AutoPref to the specified radio button, using the
			// specified preference name (and the preference value strings)
			void Attach(Dialog* pDialog,
						ControlID ListControlID,
						const vos::String& PrefName,
						bool bEnableCommitEvents = true,
						bool bEnableHistoryBehaviour = true);

			virtual void CommitPreference();

		private:
			void RestorePreferences();
			
		private:
			// Name of preference to link to
			vos::String m_PrefName;
	};

};

#endif // !vgui_AutoPrefDropDownList_h
