//
// AutoPrefTabControl.cpp - simple classes to link preferences to dialog controls.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "AutoPrefTabControl.h"

#include "vos\Preferences.h"
#include "vos\Errors.h"

namespace vgui
{
	void AutoPrefTabControl::Attach(Dialog* pDialog,
									  ControlID ListControlID,
									  const vos::String& PrefName)
	{
		// Attach control, and initialise from the preference name provided
		TabControl::Attach(pDialog, ListControlID);

		// Tell the dialog about this autopref object
		pDialog->AddAutoPref(this);

		// Remember preference name, and find the selected tab
		m_PrefName = PrefName;
		int idSelectedTab;
		if (vos::GetPreferences().Read(m_PrefName, &idSelectedTab))
		{
			m_SelectedTab = vgui::TabResourceID(idSelectedTab);
		}
	}

	void AutoPrefTabControl::CommitPreference()
	{
		// Get the currently selected tab and store it in the prefs
		vgui::TabResourceID rSelectedTab = GetSelectedTab();

		// TODO: This doesn't always work for Win32 resources, as they are
		//		 not always numeric IDs - work out how to resolve this.
		//		 Maybe have a special resource ID function for writing a
		//		 resource ID to a preference value?
		vos::GetPreferences().Write(m_PrefName, (int) rSelectedTab.GetID());
	}

	bool AutoPrefTabControl::AddTab(const TabResourceID& TabID, 
									const vos::String& TabName,
									bool bAutoSelect)
	{
		// Add the tab
		if (TabControl::AddTab(TabID, TabName) && bAutoSelect)
		{
			// Select it if it's the one we last had selected on this control
			if (TabID == m_SelectedTab)
				SelectTab(TabID);

			return true;
		}
		else
		{
			return false;
		}
	}

	bool AutoPrefTabControl::AddTab(const TabResourceID& TabID, 
									const vgui::StringResourceID& TabName,
									bool bAutoSelect)
	{
		// Add the tab
		if (TabControl::AddTab(TabID, TabName) && bAutoSelect)
		{
			// Select it if it's the one we last had selected on this control
			if (TabID == m_SelectedTab)
				SelectTab(TabID);

			return true;
		}
		else
		{
			return false;
		}
	}
};
