//
// AutoPrefTabControl.h - simple classes to link preferences to dialog controls.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_AutoPrefTabControl_h
#define vgui_AutoPrefTabControl_h

#include "IAutoPref.h"

#include "String.h"
#include "TabControl.h"

namespace vgui
{
	/**************************************************************************

	>	class AutoPrefTabControl : public TabControl, 
								   public IAutoPref


		Author:		Tim Browse
		Date:		8/6/2002

		Purpose:	Provide an auto-pref object to store/restore the 
					selected tab of a TabControl control.

	**************************************************************************/

	class AutoPrefTabControl : public TabControl, 
							   public IAutoPref
	{
		public:
			// Attach the AutoPref to the specified tab control, using the
			// specified preference name
			void Attach(Dialog* pDialog,
						ControlID ListControlID,
						const vos::String& PrefName);

			// Add a tab to the tab control
			bool AddTab(const TabResourceID& TabID, 
						const vos::String& TabName,
						bool bAutoSelect = true);
			bool AddTab(const TabResourceID& TabID, 
						const vgui::StringResourceID& TabName,
						bool bAutoSelect = true);

			virtual void CommitPreference();

		private:
			void RestorePreferences();
			
		private:
			// Name of preference to link to
			vos::String m_PrefName;

			// The selected tab
			vgui::TabResourceID m_SelectedTab;
	};

};

#endif // !vgui_AutoPrefTabControl_h
