//
// BrowseDialog.h - custom dialog for browsing for folders, printers, or computers.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_BrowseDialog_h
#define vgui_BrowseDialog_h

#include "vgui.h"
#include "vOS\vOS.h"
#include "String.h"


namespace vgui
{
	//
	// Flags to control behaviour of the browse dialog
	//
	typedef enum
	{
		// Null flags - normal behaviour
		bdf_Normal				= 0,

		//
		// This flag specifies that the returned object must already exist.
		//
		bdf_ObjectMustExist		= BIT(0),

		//
		// Shows an edit box into which the user can type an object name directly.
		//
		bdf_ShowEditBox			= BIT(1),		

		//
		// When switching between folders in the dialog, the leafname is preserved 
		// (unless bdf_ObjectMustExist is specified and the leafname doesn't exist).
		//
		bdf_PreserveLeafname	= BIT(2),

		//
		// When this flag is used, then the dialog shows a textual representation of
		// the currently selected folder, prefixed by the "StatusText" string passed
		// to the BrowseForFolder() function.
		//
		bdf_ShowFolderName		= BIT(3),
	}
	BrowseDialogFlags;

	class BrowseDialogImp;

	class BrowseDialog
	{
		public:
			BrowseDialog(BrowseDialogFlags Flags = bdf_Normal,
						 const Window* pParent = NULL);

			~BrowseDialog();

			bool BrowseForFolder(const String& Title, 
								 const String& StatusText,
								 vos::FileSpec* pResult);

		private:
			BrowseDialogImp* m_pImp;
			BrowseDialogFlags m_Flags;

			const Window* m_pParent;
	};

};

#endif // !vgui_BrowseDialog_h
