//
// CheckBox.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "CheckBox.h"

#include "CheckBoxImp.h"
#include "Window.h"
#include "String.h"
#include "Errors.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	CheckBox::CheckBox() : Window(TheFactory().MakeCheckBox()),
						   m_pDialog(NULL)
	{
		// Link back to this CheckBox object
		m_pWindowImp->SetWindowLink(this);
	}

	CheckBox& CheckBox::operator=(bool NewState)
	{
		// Set state according to flag
		if (NewState)
		{
			GetImp()->SetState(cs_Checked);
		}
		else
		{
			GetImp()->SetState(cs_Unchecked);
		}

		// Return reference
		return *this;
	}

	CheckBox& CheckBox::operator=(ControlState NewState)
	{
		// Set state
		GetImp()->SetState(NewState);

		// Return reference
		return *this;
	}

	CheckBox::operator bool()
	{
		return (GetImp()->GetState() == cs_Checked);
	}

	bool CheckBox::GetState() const
	{
		return (GetImp()->GetState() == cs_Checked);
	}

	ControlState CheckBox::GetTriState() const
	{
		return GetImp()->GetState();
	}

	bool CheckBox::Create(Window* pParent,
						const Rect& Position,
						ControlID ID)
	{
		return GetImp()->Create(pParent, Position, ID);
	}

	void CheckBox::EnableLinkedControls(Dialog* pParentDialog)
	{
		m_pDialog = pParentDialog;
	}

	void CheckBox::AddLinkedControl(ControlID ID)
	{
		// Check they've told us which dialog to link to this control
		if (m_pDialog == NULL)
		{
			COMPLAIN("AddLinkedControl() - you need to call EnableLinkedControls() first!");
			return;
		}

		m_LinkedControls.push_back(ID);

		// Make sure linked control status is up to date.
		if (GetState() == cs_Checked)
			m_pDialog->EnableControl(ID);
		else
			m_pDialog->DisableControl(ID);

	}

	void CheckBox::AddLinkedControls(const ControlID* pIDs)
	{
		// Check they've told us which dialog to link to this control
		if (m_pDialog == NULL)
		{
			COMPLAIN("AddLinkedControls() - you need to call EnableLinkedControls() first!");
			return;
		}

		bool bEnable = (GetState() == cs_Checked);

		// Add each control to our list
		while (*pIDs != NOCTL)
		{
			m_LinkedControls.push_back(*pIDs);

			// Make sure linked control status is up to date.
			if (bEnable)
				m_pDialog->EnableControl(*pIDs);
			else
				m_pDialog->DisableControl(*pIDs);

			pIDs++;
		}
	}

	void CheckBox::OnClick()
	{
		// Assume the checkbox has been changed...
		OnChanged();
	}

	void CheckBox::OnChanged()
	{
		// If we have linked controls enabled, and have some linked controls
		// available, then update the controls status based on new state of
		// the checkbox.
		if ((m_pDialog != NULL) && !m_LinkedControls.empty())
		{
			bool bEnable = (GetState() == cs_Checked);

			LinkedControls::iterator it = m_LinkedControls.begin();

			while (it != m_LinkedControls.end())
			{
				if (bEnable)
					m_pDialog->EnableControl(*it);
				else
					m_pDialog->DisableControl(*it);

				++it;
			}
		}
	}

};


