//
// CheckBox.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_CheckBox_h
#define vgui_CheckBox_h

#include "Window.h"
#include "String.h"
#include "Controls.h"

namespace vgui
{
	class CheckBoxImp;

	typedef std::vector<ControlID> LinkedControls;

	class CheckBox : public Window
	{
		public:
			CheckBox();

			CheckBox& operator=(bool NewState);
			CheckBox& operator=(ControlState NewState);

			operator bool();

			bool GetState() const;
			ControlState GetTriState() const;

			// Specifying NOCTL will result in a unique control ID being chosen for you.
			bool Create(Window* pParent,
						const Rect& Position,
						ControlID ID = NOCTL);
			
			// Called whenever the checkbox is clicked on
			virtual void OnClick();

			// Called whenever the checkbox state is changed
			virtual void OnChanged();

			// Allows a checkbox to fade/unfade one or more controls automatically
			void EnableLinkedControls(Dialog* pParentDialog);
			void AddLinkedControl(ControlID ID);
			void AddLinkedControls(const ControlID* pIDs);

		private:
			CheckBoxImp* GetImp() const { return (CheckBoxImp*) m_pWindowImp; }

		private:
			// Copying objects of this class is prohibited
			CheckBox& operator=(const CheckBox& rhs);

		private:
			LinkedControls m_LinkedControls;
			Dialog* m_pDialog;
	};
};

#endif // !vgui_CheckBox_h
