//
// Colour.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//


#include "StdHdr.h"

#include "Colour.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif


namespace vgui
{

#ifdef VGUI_MSWINDOWS

	DWORD ColourTable[] = 
	{
		COLOR_WINDOW,			// Colour_WindowBackground
		COLOR_WINDOWTEXT,		// Colour_WindowText
		COLOR_HIGHLIGHT,		// Colour_SelectedBackground
		COLOR_HIGHLIGHTTEXT,	// Colour_SelectedText
	};

#endif

	// Built-in colours
	Colour Colour::Black(0,0,0);
	Colour Colour::White(255,255,255);
	Colour Colour::Grey(128,128,128);
	Colour Colour::LightGrey(224,224,224);
	Colour Colour::DarkGrey(64,64,64);
	Colour Colour::DarkRed(255,0,0);
	Colour Colour::Red(255,0,0);
	Colour Colour::DarkOrange(192,92,0);
	Colour Colour::Orange(255,128,0);
	Colour Colour::DarkGreen(0,192,0);
	Colour Colour::Green(0,255,0);
	Colour Colour::DarkBlue(0,0,192);
	Colour Colour::Blue(0,0,255);
	Colour Colour::Cyan(0,255,255);
	Colour Colour::Magenta(255,0,255);
	Colour Colour::Yellow(255,255,0);
	Colour Colour::DarkYellow(192,192,0);

	
/**************************************************************************

>	Colour Colour::GetGUIColour(TColour Colour)

	Author:		Tim Browse
	Date:		04/03/2001
	Inputs:		The GUI colour to access
	Returns:	The colour of the requested item.

	Purpose:	Get the colour value for a specific GUI element, such
				as the default window background colour, or highlight
				colour, etc.

**************************************************************************/

Colour Colour::GetGUIColour(TColour Colour)
	{
#ifdef VGUI_MSWINDOWS

		// Ask Windows for the system colour
		DWORD dwColour = ::GetSysColor(ColourTable[Colour]);

		// Convert to our own colour format
		vgui::Colour GUIColour;
		GUIColour.m_Red   = GetRValue(dwColour);
		GUIColour.m_Green = GetGValue(dwColour);
		GUIColour.m_Blue  = GetBValue(dwColour);
		return GUIColour;

#elif defined VGUI_MACOS

		// XXX - TODO
		// We need to have registered an appearance client... 
		// And now we can get the colour,
		// having converted the TColour to a meaningful enumeration
		
		vgui::Colour GUIColour;
		return GUIColour;

#else

#error GetGUIColour() needs porting

#endif
	}

};
