//
// Colour.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Colour_h
#define vgui_Colour_h

#include "vgui.h"

namespace vgui
{
	typedef enum
	{
		Colour_WindowBackground,
		Colour_WindowText,

		Colour_SelectedBackground,
		Colour_SelectedText,
	}
	TColour;

	//
	// Simple colour class for RGB colours.
	//
	// Designed to fit in 32-bit word.
	//
	// For HSV, CMYK support, etc. see the ExtColour class.
	//
	class Colour
	{
		public:
			//
			// Constructors
			//
			Colour() : m_Red(0), 
					   m_Green(0), 
					   m_Blue(0) 
			{
			}

			Colour(byte Red, 
				   byte Green, 
				   byte Blue) : m_Red(Red),
									 m_Green(Green),
									 m_Blue(Blue)
			{
			}

			// Copy constructor
			Colour(const Colour& rhs)
			{
				m_Red   = rhs.m_Red;
				m_Green = rhs.m_Green;
				m_Blue  = rhs.m_Blue;
			}

			// Assignment
			Colour& operator=(const Colour& rhs)
			{
				m_Red   = rhs.m_Red;
				m_Green = rhs.m_Green;
				m_Blue  = rhs.m_Blue;

				return *this;
			}

			// Colour component access
			byte GetRed() const { return m_Red; }
			byte GetGreen() const { return m_Green; }
			byte GetBlue() const { return m_Blue; }

			void SetRed(byte Red) { m_Red = Red; }
			void SetGreen(byte Green) { m_Green = Green; }
			void SetBlue(byte Blue) { m_Blue = Blue; }

			static Colour GetGUIColour(TColour Colour);

#if defined VGUI_MACOS
			//
			// Carbon specific functions
			//
			
			// Return a Carbon RGBColor reference
			::RGBColor& GetRGBColor() const
			{ 
				// Scale the values up to RGBColor component size 0..65535
				m_RGBColor.red = m_Red * 255;
				m_RGBColor.green = m_Green * 255; 
				m_RGBColor.blue = m_Blue * 255; 
				return m_RGBColor;
			}

			// Set the values of this colour to be the values from an 
			// existing RGBColor structure.
			void Set(::RGBColor const& c)
			{
				m_Red = c.red;
				m_Blue = c.blue;
				m_Green = c.green;
			}
			
		private:
			mutable ::RGBColor	m_RGBColor;
#endif

		public:
			//
			// Built-in colours
			//
			static Colour Black;
			static Colour White;
			static Colour Grey;
			static Colour LightGrey;
			static Colour DarkGrey;
			static Colour Red;
			static Colour DarkRed;
			static Colour Orange;
			static Colour DarkOrange;
			static Colour Green;
			static Colour DarkGreen;
			static Colour Blue;
			static Colour DarkBlue;
			static Colour Cyan;
			static Colour Magenta;
			static Colour Yellow;
			static Colour DarkYellow;

		protected:
			byte m_Red, m_Green, m_Blue;
	};
};

#endif // !vgui_Colour_h


