//
// DialogImp.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_DialogImp_h
#define vgui_DialogImp_h

#include "vgui.h"

#include "Dialog.h"

#include "WindowImp_OS.h"

namespace vgui
{
	class DialogImp : public WindowImp_OS
	{
		public:
			virtual ControlID DoModalDialog(const DialogResourceID DialogID,
											const Window *pParent,
											WindowPos Pos) = 0;

			virtual void DoModelessDialog(const DialogResourceID DialogID,
										  const Window *pParent,
										  WindowPos Pos,
										  TShowWindow Show) = 0;

			virtual void EndDialog(ControlID ID) = 0;

			virtual bool Create(const DialogResourceID DialogID,
								const Window *pParent) = 0;
			
			virtual void DisableAutoResizeGripper() = 0;

			virtual void EnableDialogControl(ControlID ID, bool bEnable) = 0;

			virtual void MoveControl(ControlID ID, int x, int y) = 0;
			virtual void MoveControlRelative(ControlID ID, int DeltaX, int DeltaY) = 0;
			virtual void ResizeControl(ControlID ID, int Width, int Height) = 0;
			virtual void EnableControl(ControlID ID) = 0;
			virtual void DisableControl(ControlID ID) = 0;
			virtual void ShowControl(ControlID ID) = 0;
			virtual void HideControl(ControlID ID) = 0;
			virtual void GetControlPosition(ControlID, Rect* pPosition) = 0;
			virtual void SetControlPosition(ControlID ID, const Rect& Position) = 0;
			virtual void SetControlState(ControlID ID, ControlState NewState) = 0;
			virtual ControlState GetControlState(ControlID ID) = 0;
			virtual bool FindControlWindow(ControlID ID, Window** ppWindow) = 0;

			//
			// Functions to lock window update for dialog controls - so many controls
			// can be repositioned/resized in one go without flicker
			//
			virtual void LockControlUpdate() = 0;
			virtual void UnlockControlUpdate() = 0;

			//
			// Convenience function
			//
			Dialog* GetDialog() { return (Dialog*) GetWindowLink(); }
	};
};

#endif // !vgui_DialogImp_h
