//
// DocViewTemplate.cpp - template for linking view types to document types.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "DocViewTemplate.h"

#include "Document.h"
#include "View.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	DocViewTemplate::DocViewTemplate(Document* pDocument, 
									 View* pView) : m_pDocument(pDocument),
													m_pView(pView)
	{
	}

	DocViewTemplate::~DocViewTemplate()
	{
		// Dispose of our template objects
		delete m_pDocument;
		delete m_pView;
	}

	Document* DocViewTemplate::GetDocument()
	{
		return m_pDocument;
	}

	View* DocViewTemplate::GetView()
	{
		return m_pView;
	}

	DocViewTemplates::~DocViewTemplates()
	{
		// Delete all doc view templates
		while (begin() != end())
		{
			// Get first template
			DocViewTemplate* pTemplate = *(begin());

			// Remove it from the list
			erase(begin());

			// Delete the template
			delete pTemplate;
		}
	}

};

