//
// DocumentApplication.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_DocumentApplication_h
#define vgui_DocumentApplication_h

#include "vgui.h"

#include "Application.h"
#include "DocViewTemplate.h"
#include "Document.h"

namespace vgui
{
	class DocumentApplication : public Application
	{
		public:
			DocumentApplication();
			~DocumentApplication();

		public:
			// Accessors
			View* GetActiveView() const { return m_pActiveView; }

		public:
			// Command handling
			virtual bool OnCommand(int nCommand);

			// Document handling
			virtual bool OnNewDocument();

			// You must provide an implementation in your application that
			// installs doc/view prototype objects.
			// (See AddDocViewTemplate()).
			virtual void CreateDocViewTemplates() = 0;

			// View activation handling
			void NotifyViewActivated(View* pActiveView);
			void NotifyViewDeactivated(View* pActiveView);

			virtual bool OnCloseView(View* pViewToClose);

			virtual bool CreateMainWindowObject();

			virtual bool OnClose();

		public:
			// Initialisation - for use in CreateDocViewTemplates().
			void AddDocViewTemplate(Document* pDocumentPrototype,
									View* pViewPrototype);

		protected:
			// Documents currently open in this application
			Documents m_Documents;

			// Current active view
			View* m_pActiveView;

			// The document/view templates.  This is one or more pairs of
			// document and view prototype objects.  These objects are cloned
			// whenever we need to create a new document/view pair.
			//
			// When there is more than one doc/view pair, the user is given
			// a choice as to what type of document they want to create.
			//
			// These objects are never used other than as prototypes.
			//
			static DocViewTemplates s_DocViewTemplates;
	};

	class ApplicationMDI : public DocumentApplication
	{
		public:
			ApplicationMDI();

			virtual void Init();
	};
};

#endif // !vgui_DocumentApplication_h


