//
// DropDownList.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "DropDownList.h"

#include "DropDownListImp.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	DropDownList::DropDownList() : ListControl(TheFactory().MakeDropDownList()),
								   m_bHasHistoryBehaviour(false)
	{
		// Already linked back to this DropDownList object by the base class,
		// so we don't need to call SetWindowLink here.
	}

	DropDownList& DropDownList::operator=(const String& ItemName)
	{
		if (!SelectByString(ItemName))
		{
			// This string doesn't exist in the list, so just set
			// the text on the window.
			SetText(ItemName);
		}
		
		return *this;
	}

	DropDownList& DropDownList::operator=(const StringResourceID& ItemName)
	{
		if (!SelectByResID(ItemName))
		{
			// This string doesn't exist in the list, so just set
			// the text on the window.
			SetText(ItemName.Load());
		}

		return *this;
	}

	DropDownList::operator String()
	{
		// Get the text into a local String object
		String Text;
		GetImp()->GetText(Text);

		// And return to caller
		return Text;
	}


	void DropDownList::ClearTextSelection()
	{
		GetImp()->ClearTextSelection();
	}
	
	void DropDownList::EnableHistoryBehaviour(bool bEnable)
	{
		GetImp()->EnableHistoryBehaviour(bEnable);
		m_bHasHistoryBehaviour = bEnable;
	}

	bool DropDownList::HasHistoryBehaviour() const
	{
		return m_bHasHistoryBehaviour;
	}
	
	void DropDownList::CommitToHistory(const vos::String& Text)
	{
		GetImp()->CommitToHistory(Text);
	}

	void DropDownList::CommitCurrentTextToHistory()
	{
		vos::String Text;
		if (GetImp()->GetText(Text) && !Text.IsEmpty())
		{
			CommitToHistory(Text);
		}
	}
	
	void DropDownList::EnableCommitNotification(bool bEnable)
	{
		// Let the implementation object know, in case any other
		// work needs to be done (e.g. Win32's bizarre combobox design)
		GetImp()->EnableCommitNotification(bEnable);
	}

	void DropDownList::InsertTextAtCursor(const String& Text, EditBoxBehaviour Behaviour)
	{
		GetImp()->InsertTextAtCursor(Text, Behaviour);
	}

};

