//
// DropDownList.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_DropDownList_h
#define vgui_DropDownList_h

#include "vgui.h"

#include "ListControl.h"
#include "String.h"
#include "ResourceID.h"

#include <vector>

namespace vgui
{
	class DropDownListImp;

	class DropDownList : public ListControl
	{
		public:
			DropDownList();

			// We have to reimplement the assignment operators - they don't
			// seem to be inherited from the base class.
			DropDownList& operator=(const String& ItemName);
			DropDownList& operator=(const StringResourceID& ItemName);

			// Get the contents of the selected item as a string
			operator String();

			// Manipulate the text if the text is editable
			void InsertTextAtCursor(const String& Text, 
									EditBoxBehaviour Behaviour = eb_Normal);

			// Clear selection of editable field, if the control has one.
			virtual void ClearTextSelection();

			// Control whether this control should use 'history'
			// behaviour, which works as follows:
			// 
			// * When an item is selected in the list, it is promoted to 
			//   the top of the list.
			//
			// * CommitToHistory() becomes available to call.
			//
			void EnableHistoryBehaviour(bool bEnable = true);

			bool HasHistoryBehaviour() const;

			// History behaviour must be on before you call these:
			void CommitToHistory(const vos::String& Text);
			void CommitCurrentTextToHistory();
			void SetHistoryLimit(int Limit = 20);
			
			// Control handling of return key in edit control
			void EnableCommitNotification(bool bEnable = true);

		private:
			DropDownListImp* GetImp() const { return (DropDownListImp*) m_pWindowImp; }

		private:
			// Copying objects of this class is prohibited
			DropDownList& operator=(const DropDownList& rhs);

		private:
			bool m_bHasHistoryBehaviour;
	};
};

#endif // !vgui_DropDownList_h
