//
// EditBox.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "EditBox.h"

#include "EditBoxImp.h"
#include "Window.h"
#include "String.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	EditBox::EditBox() : Window(TheFactory().MakeEditBox()),
						 m_bSendCommitNotification(false),
						 m_pNotifyWindow(NULL),
						 m_NotifyControlID(NOCTL)
	{
		// Link back to this EditBox object
		m_pWindowImp->SetWindowLink(this);
	}

	EditBox& EditBox::operator=(const String& Text)
	{
		// Set text
		GetImp()->SetText(Text);

		// Return reference
		return *this;
	}

	EditBox& EditBox::operator=(const char *pText)
	{
		// Create temporary string
		String Text;
		Text.assign(pText);

		// Set text
		GetImp()->SetText(Text);

		// Return reference
		return *this;
	}

	EditBox::operator String()
	{
		// Get the text into a local String object
		String Text;
		GetImp()->GetText(Text);

		// And return to caller
		return Text;
	}

	void EditBox::GetText(String* pText)
	{
		GetImp()->GetText(*pText);
	}

	void EditBox::AppendText(const String& Text)
	{
		GetImp()->AppendText(Text);
	}

	void EditBox::InsertTextAtCursor(const String& Text, EditBoxBehaviour Behaviour)
	{
		GetImp()->InsertTextAtCursor(Text, Behaviour);
	}

	bool EditBox::Create(Window* pParent, const Rect& rcPosition, ControlID ID)
	{
		if (GetImp()->Create(pParent, rcPosition, ID))
		{
			m_pParent = pParent;
			return true;
		}
		else
		{
			return false;
		}
	}

	bool EditBox::OnKeyDown(vgui::TKeyCode Key, int Modifiers)
	{
		if (m_bSendCommitNotification && (Key == vgui::kc_Return))
		{
			// Return pressed in edit box - tell parent window about
			// this, assuming we have one.

			// We vector notifications elsewhere if we have been told
			// to do this...
			//
			// (If you're wondering, this is to cope with Win32 combo
			//  box design flaws).
			//
			Window* pWindowToNotify = m_pNotifyWindow;
			if (pWindowToNotify == NULL)
			{
				pWindowToNotify = m_pParent;
			}

			if (pWindowToNotify != NULL)
			{
				ControlID ID = m_NotifyControlID;
				if (ID == NOCTL)
				{
					ID = GetControlID();
				}

				return pWindowToNotify->OnMessage(mt_EBN_TEXTCOMMIT, 0, ID);
			}
		}

		// Don't claim this message, or we'll upset the
		// usual dialog handling
		return false;
	}

	bool EditBox::OnChar(uint16 Char)
	{
		// If we're processing text commits, then eat any CR characters
		// that come through (as we process them on the KeyDown event)
		return (m_bSendCommitNotification && (Char == 13));
	}

	bool EditBox::IsCharWanted(uint16 Char)
	{
		// If we're processing text commits, then tell the GUI that we
		// want CR characters, so they don't go anywhere else and confuse
		// things.
		return (m_bSendCommitNotification && (Char == 13));
	}

	bool EditBox::IsKeyWanted(TKeyCode Key)
	{
		// If we need to send text commit notifications, then we need to
		// receive the CR event (as opposed to passing it on to the parent
		// dialog/window).
		return (m_bSendCommitNotification && (Key == vgui::kc_Return));
	}

	void EditBox::EnableCommitNotification(bool bEnable)
	{
		m_bSendCommitNotification = bEnable;
	}

	void EditBox::SendNotificationsTo(Window* pNotifyWindow, 
									  ControlID ControlIDToUse)
	{
		m_pNotifyWindow = pNotifyWindow;
		m_NotifyControlID = ControlIDToUse;
	}

};


