//
// EditBox.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_EditBox_h
#define vgui_EditBox_h

#include "Window.h"
#include "String.h"

namespace vgui
{
	class EditBoxImp;

	class EditBox : public Window
	{
		public:
			EditBox();

			EditBox& operator=(const String& Text);
			EditBox& operator=(const char *pText);

			operator String();

			void GetText(String* pText);

			void AppendText(const String& Text);
			void InsertTextAtCursor(const String& Text, EditBoxBehaviour Behaviour = eb_Normal);

			bool Create(Window* pParent, const Rect& rcPosition, ControlID ID);

			// Control handling of return key in edit control
			void EnableCommitNotification(bool bEnable = true);

			// Direct the control to send notifications somewhere other
			// than the default.
			void SendNotificationsTo(Window* pNotifyWindow, ControlID ControlIDToUse);

		public:
			// Message handlers
			bool OnKeyDown(vgui::TKeyCode Key, int Modifiers);
			bool IsKeyWanted(TKeyCode Key);
			bool IsCharWanted(uint16 Char);
			bool OnChar(uint16 Char);

		private:
			EditBoxImp* GetImp() const { return (EditBoxImp*) m_pWindowImp; }

		private:
			// Copying objects of this class is prohibited
			EditBox& operator=(const EditBox& rhs);

		private:
			bool m_bSendCommitNotification;

			// If we are redirecting our notification messages, then these
			// fields specify where the messages should go.
			Window* m_pNotifyWindow;
			ControlID m_NotifyControlID;
	};
};

#endif // !vgui_EditBox_h
