//
// Errors.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Errors.h"
#include "vos\ErrorCodes.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	Error RegisterError_Res(int Code, 
						    vos::TErrorType Type, 
							StringResourceID ErrMsgID,
							char* szSourceFile,
							int LineNumber)
	{
		// Load localised error message
		String ErrMsg;

		if (ErrMsgID.Load(&ErrMsg))
		{
			// Successfully loaded the error message
			return vos::TheErrorManager().RegisterError(Code, 
														Type, 
														ErrMsg.c_str(),
														szSourceFile,
														LineNumber);
		}
		else
		{
			// Unable to load the error message - report the error numerically, and
			// fall back to nonlocalised error message.

			ErrMsg = "Unable to load error message (";
			ErrMsg += ErrMsgID.GetID();
			ErrMsg += ") - please contact technical support";

			return vos::TheErrorManager().RegisterError(Err_GenericError, 
														Type, 
														ErrMsg.c_str(),
														szSourceFile,
														LineNumber);
		}
	}
};
