//
// Errors.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Errors_h
#define vgui_Errors_h

#include "ResourceID.h"

#include "vos\Errors.h"

//
// Some macros to interface to the error manager.
//
// NB. This is one possible interface to the error manager - you
//     don't have to use it.
//
// This file builds on vos\Errors.h and adds support for string resource IDs
// instead of raw string messages (makes localisation of error messages easier).

namespace vgui
{
	extern Error RegisterError_Res(int Code, 
								   vos::TErrorType Type, 
								   StringResourceID ErrMsgID,
								   char* szSourceFile = NULL,
								   int LineNumber = 0);
};

#ifdef _DEBUG

#define ERROR_RES(ErrCode, rReason) \
		vgui::RegisterError_Res(ErrCode, vos::Error_Normal, rReason, __FILE__, __LINE__)

#define CRITICAL_ERROR_RES(ErrCode, rReason) \
		vgui::RegisterError_Res(ErrCode, vos::Error_Critical, rReason, __FILE__, __LINE__)

#define TERMINAL_ERROR_RES(ErrCode, rReason) \
		vgui::RegisterError_Res(ErrCode, vos::Error_Terminal, rReason, __FILE__, __LINE__)

#else

#define ERROR_RES(ErrCode, rReason) \
		vgui::RegisterError_Res(ErrCode, vos::Error_Normal, rReason)

#define CRITICAL_ERROR_RES(ErrCode, rReason) \
		vgui::RegisterError_Res(ErrCode, vos::Error_Critical, rReason)

#define TERMINAL_ERROR_RES(ErrCode, rReason) \
		vgui::RegisterError_Res(ErrCode, vos::Error_Terminal, rReason)

#endif

#endif // !vgui_Errors_h
