//
// FileDialogParams.h - dialogs for dealing with file open/save
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_FileDialog_h
#define vgui_FileDialog_h

#include "vgui.h"
#include "String.h"
#include "Dialog.h"

#include "vOS\FileSpec.h"

#include "DocumentClass.h"

#define kFilterBufSize (128)

namespace vgui
{
	using vos::FileSpec;

	class FileDialogParams
	{
		public:
			FileDialogParams();

		public:
			// Title of the save dialog
			vos::String m_DialogTitle;

			// Initial folder to open the dialog at.
			// If empty, initial folder is chosen automatically, as appropriate for
			// the platform.  The folder eventually accepted by the user is written 
			// back into this member data, to allow persistence of user choices by
			// reusing this FileOpenDialogParams object.
			FileSpec m_InitialFolder;

			// Flags to control behaviour of dialog - see above.
			uint m_Flags;

			// Type of files to show in the dialog
			DocumentClasses m_FileClasses;

			//
			// Platform dependent data...
			//

#if VGUI_MSWINDOWS
			// The extension filters.
			char m_szFileFilters[kFilterBufSize];

			// Default file extension to add if the user does not specify one
			vos::String m_DefaultExtension;

			// Private data used by SaveDialog class to maintain persistence
			int m_nFilterIndex;
#endif
	};

};

#endif // !vgui_FileOpenDialog_h
