//
// Font.h - Font objects
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Font_h
#define vgui_Font_h

#include "vgui.h"

#include "String.h"

namespace vgui
{
	class FontImp;

	//
	// Enum for the weight of fonts.
	//
	typedef enum
	{
		fw_Light,
		fw_Normal,
		fw_Bold,
	}
	FontWeight;

	//
	// Enum for the style of fonts.
	//
	typedef enum
	{
		fs_Normal		= 0,
		fs_Italic		= BIT(1),
		fs_Underline	= BIT(2),
	}
	FontStyle;

	//
	// Enum for the pitch of the typeface.
	typedef enum
	{
		fp_DefaultPitch,
		fp_FixedPitch,
		fp_VariablePitch,
	}
	FontPitch;

	//
	//
	// Enum for the family of typeface.
	//
	typedef enum
	{
		ff_Default,
		ff_Roman,
		ff_Swiss,
	}
	FontFamily;

	class Font
	{
		public:

			//
			// Constructor/Destructor
			//
			Font();
			~Font();

			// Creating a font.
			bool Create(const String& TypefaceName,
						uint PointSize,
						FontWeight Weight = fw_Normal,
						FontStyle Style = fs_Normal,
						FontFamily Family = ff_Default,
						FontPitch Pitch = fp_DefaultPitch);

			// Query font dimensions
			uint GetHeightInPixels();
			uint GetHeightInPoints();

		public:
			FontImp* GetImp() { return m_pFontImp; }

		private:
			// The implementation of this Font.
			// (Pattern: Bridge)
			FontImp *m_pFontImp;

		private:
			// Prohibit copying/assignment of Fonts - clients should use
			// pointers/references to Fonts if they are to be shared.
			Font(const Font&);
			Font& operator=(const Font&);
	};
};

#endif // !vgui_Font_h


