//
// GC.cpp - Graphics Context
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "GC.h"

#include "GCImp.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	GC::GC() : m_pGCImp(NULL)
	{
		// Create the implementation object.
		m_pGCImp = TheFactory().MakeGC();
	}

	GC::GC(GCImp *pImp) : m_pGCImp(pImp)
	{
		// We've already got an implementation object.
	}

	GC::GC(Window *pWindow) : m_pGCImp(NULL)
	{
		// Create the implementation object.
		m_pGCImp = TheFactory().MakeGC();

		// Attach the GC to the window
		m_pGCImp->Attach(pWindow);
	}

	GC::~GC()
	{
		delete m_pGCImp;
	}

	//
	// Drawing Attributes
	//

	// Save/restore entire GC state
	void GC::Save()
	{
		m_pGCImp->Save(); 
	}

	void GC::Restore()
	{
		m_pGCImp->Restore(); 
	}

	void GC::SetStrokeStyle(StrokeStyle Style) 
	{
		m_pGCImp->SetStrokeStyle(Style); 
	}

	void GC::SetFillColour(const Colour& FillColour)
	{
		m_pGCImp->SetFillColour(FillColour);
	}

	void GC::SetFillStyle(FillStyle Style)
	{
		m_pGCImp->SetFillStyle(Style);
	}

	void GC::SetStrokeColour(const Colour& StrokeColour)
	{
		m_pGCImp->SetStrokeColour(StrokeColour);
	}

	void GC::SetBgColour(const Colour& BgColour)
	{
		m_pGCImp->SetBgColour(BgColour);
	}

	Colour GC::SetTextColour(const Colour& TextColour)
	{
		return m_pGCImp->SetTextColour(TextColour);
	}

	void GC::SetBgMode(GC::BgMode Mode)
	{
		m_pGCImp->SetBgMode(Mode);
	}

	void GC::SetStrokeWidth(int Width)
	{
		m_pGCImp->SetStrokeWidth(Width);
	}

	// Drawing lines
	void GC::MoveTo(int x, int y)
	{
		m_pGCImp->MoveTo(x, y);
	}

	void GC::LineTo(int x, int y)
	{
		m_pGCImp->LineTo(x, y);
	}

	// Simple shapes
	void GC::DrawRect(const Rect& rc, GC::DrawType Type)
	{
		m_pGCImp->DrawRect(rc, Type);
	}

	void GC::DrawCircle(int cx, int cy, int Radius, GC::DrawType Type)
	{
		m_pGCImp->DrawCircle(cx, cy, Radius, Type);
	}

	// Polygons
	void GC::DrawPolygon(const Point* pts,
						 int cPoints,
						 GC::DrawType Type)
	{
		m_pGCImp->DrawPolygon(pts, cPoints, Type);
	}

	void GC::DrawPolygon(const Points& pts,
						 GC::DrawType Type)
	{
		m_pGCImp->DrawPolygon(pts, Type);
	}

	void GC::DrawText(const String& Text, int x, int y)
	{
		m_pGCImp->DrawText(Text, x, y);
	}

	void GC::DrawText(const String& Text, 
					  const Rect& TextArea,
					  int FormatFlags)
	{
		m_pGCImp->DrawText(Text, TextArea, FormatFlags);
	}

	void GC::CalcTextArea(const String& Text,
						  int FormatFlags,
						  Rect* pTextArea)
	{
		m_pGCImp->CalcTextArea(Text, FormatFlags, pTextArea);
	}

	void GC::SetFont(Font* pFont)
	{
		m_pGCImp->SetFont(pFont);
	}

	void GC::RestoreDefaultFont()
	{
		m_pGCImp->RestoreDefaultFont();
	}

	void GC::Draw3DEdge(const Rect& TheRect, Edge3DType EdgeType)
	{
		m_pGCImp->Draw3DEdge(TheRect, EdgeType);
	}
	
	void GC::DrawFocusRect(const Rect& TheRect)
	{
		m_pGCImp->DrawFocusRect(TheRect);
	}

	void GC::BeginDrawing()
	{
		m_pGCImp->BeginDrawing();
	}
	
	void GC::EndDrawing()
	{
		m_pGCImp->EndDrawing();
	}

	void GC::GetClipRect(Rect* pClipRect)
	{
		m_pGCImp->GetClipRect(pClipRect);
	}

	void GC::DrawIcon(const Icon& Icon, int X, int Y)
	{
		m_pGCImp->DrawIcon(Icon, X, Y);
	}

};




