//
// GCImp.h - Graphics Context implementation interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_GCImp_h
#define vgui_GCImp_h

#include "vgui.h"

#include "GC.h"

namespace vgui
{
	class GCImp
	{
		public:
			// Ensure virtual destructor.
			virtual ~GCImp() {}

			//
			// Attach/detach to/from window
			//
			virtual bool Attach(Window *pWindow) = 0;
			virtual void Detach() = 0;

			// Clip rectangle
			virtual void GetClipRect(Rect* pClipRect) = 0;

			//
			// Drawing Attributes
			//

			// Save/restore entire GC state
			virtual void Save() = 0;
			virtual void Restore() = 0;

			// Line/Fill style
			virtual void SetStrokeStyle(GC::StrokeStyle Style) = 0;
			virtual void SetFillStyle(GC::FillStyle Style) = 0;

			virtual void SetFillColour(const Colour& FillColour) = 0;
			virtual void SetStrokeColour(const Colour& FgColour) = 0;

			virtual void SetBgColour(const Colour& BgColour) = 0;
			virtual void SetBgMode(GC::BgMode Mode) = 0;

			virtual Colour SetTextColour(const Colour& TextColour) = 0;

			virtual void SetStrokeWidth(int Width) = 0;

			// Drawing lines
			virtual void MoveTo(int x, int y) = 0;
			virtual void LineTo(int x, int y) = 0;

			// Simple shapes
			virtual void DrawRect(const Rect& rc,
								  GC::DrawType Type = GC::dt_FillAndStroke) = 0;

			virtual void DrawCircle(int cx, int cy, int Radius,
									GC::DrawType Type = GC::dt_FillAndStroke) = 0;

			// Polygons
			virtual void DrawPolygon(const Point* pts,
									 int cPoints,
									 GC::DrawType Type = GC::dt_FillAndStroke) = 0;

			virtual void DrawPolygon(const Points& pts,
									 GC::DrawType Type = GC::dt_FillAndStroke) = 0;

			// Text rendering

			virtual void SetFont(Font* pFont) = 0;
			virtual void RestoreDefaultFont() = 0;

			virtual void DrawText(const String& Text, int x, int y) = 0;

			virtual void DrawText(const String& Text, 
								  const Rect& TextArea,
								  int FormatFlags) = 0;

			virtual void CalcTextArea(const String& Text,
									  int FormatFlags,
									  Rect* pTextArea) = 0;

			// Specialised rendering
			virtual void Draw3DEdge(const Rect& TheRect, Edge3DType EdgeType) = 0;
			virtual void DrawFocusRect(const Rect& TheRect) = 0;

			// Image/bitmap rendering
			virtual void DrawIcon(const Icon& Icon, int X, int Y) = 0;

			// GC Focus
			
			virtual void BeginDrawing() = 0;
			virtual void EndDrawing() = 0;

			// Co-ordinate functions

	};
};

#endif // !vgui_GCImp_h


