//
// GCState.h - Encapsulate a GC state
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_GCState_h
#define vgui_GCState_h

#include <stack>
#include <list>

#include "GC.h"

namespace vgui
{
	class Pen;
	class Brush;
	class Font;
	class ClipRegion;

	/**************************************************************************

		class GCState

		Author:		Tim Browse
		Date:		22/7/99
		Purpose:	Encapsulate the state of a Graphics Context (GC)

	**************************************************************************/

	class GCState
	{
		public:
			GCState();

		public:
			// Graphical state
			GC::StrokeStyle m_StrokeStyle;
			Colour m_StrokeColour;
			int m_StrokeWidth;

			GC::FillStyle m_FillStyle;
			Colour m_FillColour;

			Colour m_BgColour;
			GC::BgMode m_BgMode;

			Colour m_TextColour;

			Font* m_pFont;
	};

	// 
	// Name useful STL type
	//

	typedef std::stack<GCState> GCStateStack;
};

#endif // !vgui_GCState_h
