//
// JobWorker.cpp
//

#include "StdHdr.h"

#include "JobWorker.h"

namespace vgui
{
	/**************************************************************************
	
	>	JobWorker::~JobWorker()
	
		Author:		Tim Browse
		Date:		30/4/2002
	
		Purpose:	Virtual destructor
	
	**************************************************************************/
	
	JobWorker::~JobWorker()
	{
		// TDILB
	}

	/**************************************************************************
	
	>	void JobWorker::DoWork(vgui::JobController* pJobController,)
	
		Author:		Tim Browse
		Date:		30/4/2002
		Inputs:		pJobController - optional job controller, may be NULL

		Purpose:	Get the object to complete all its work, without using a
					vgui ProgressDialog object (i.e. no progress display will
					be shown).
	
	**************************************************************************/
	
	void JobWorker::DoAllWork(vgui::JobController* pJobController)
	{
		// If no controller is passed in, use a null controller
		vgui::JobController DummyController;

		if (pJobController == NULL)
		{
			pJobController = &DummyController;
		}

		int PercentComplete;
		while (DoWork(pJobController, &PercentComplete) == Job_NotFinished)
		{
			// ILB
		}
	}

	/**************************************************************************
	
	>	void JobWorker::OnCancel(JobController* pJobController)
	
		Author:		Tim Browse
		Date:		3/5/2002
		Inputs:		pJobController - the job controller in charge of this job
	
		Purpose:	The job has been cancelled, so get the object to do any
					clean up it has to do.
	
	**************************************************************************/
	
	void JobWorker::OnCancel(JobController* pJobController)
	{
		// Default is to do nothing...
	}

	/**************************************************************************
	
	>	JobWorkerWrapper::JobWorkerWrapper(JobWorker* pWorker)
	
		Author:		Tim Browse
		Date:		8/8/2002
		Inputs:		pWorker - the work object to wrap.  All interface calls
							  will be directed to this object.
	
		Purpose:	Construct a JobWorkerWrapper object that wraps the
					specified JobWorker object.
	
	**************************************************************************/
	
	JobWorkerWrapper::JobWorkerWrapper(JobWorker* pWorker) : m_pWorker(pWorker)
	{
		// TCILB
	}

	TJobStatus JobWorkerWrapper::DoWork(JobController* pJobController,
									    int* pPercentComplete)
	{
		return m_pWorker->DoWork(pJobController, pPercentComplete);
	}

	void JobWorkerWrapper::OnCancel(JobController* pJobController)
	{
		m_pWorker->OnCancel(pJobController);
	}
};

