//
// Keyboard.h - constants for key presses
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Keyboard_h
#define vgui_Keyboard_h

namespace vgui
{
	typedef enum
	{
		kc_Invalid = 0,

		kc_Backspace = 8,
		kc_Tab = 9,
		kc_Return = 13,
		kc_Escape = 27,

		// Printable ASCII
		kc_Space = ' ',

		kc_0 = '0',
		kc_1 = '1',
		kc_2 = '2',
		kc_3 = '3',
		kc_4 = '4',
		kc_5 = '5',
		kc_6 = '6',
		kc_7 = '7',
		kc_8 = '8',
		kc_9 = '9',

		// Letter keys
		kc_A = 65,
		kc_B,
		kc_C,
		kc_D,
		kc_E,
		kc_F,
		kc_G,
		kc_H,
		kc_I,
		kc_J,
		kc_K,
		kc_L,
		kc_M,
		kc_N,
		kc_O,
		kc_P,
		kc_Q,
		kc_R,
		kc_S,
		kc_T,
		kc_U,
		kc_V,
		kc_W,
		kc_X,
		kc_Y,
		kc_Z,

		kc_Comma,
		kc_Period,
		kc_ForwardSlash,
		kc_Colon,
		kc_Apostrophe,
		kc_Hash,
		kc_LeftSquareBracket,
		kc_RightSquareBracket,

		// Numpad
		kc_NumpadPeriod,
		kc_NumpadPlus,
		kc_NumpadMinus,
		kc_NumpadDivide,
		kc_NumpadMultiply,

		// Cursor keys
		kc_Left = 0x80,
		kc_Right,
		kc_Up,
		kc_Down,

		// Navigation
		kc_Home,
		kc_End,
		kc_PageUp,
		kc_PageDown,

		// Modifiers
		kc_Shift,
		kc_Control,
		kc_Alt,

		// Function keys
		kc_F1,
		kc_F2,
		kc_F3,
		kc_F4,
		kc_F5,
		kc_F6,
		kc_F7,
		kc_F8,
		kc_F9,
		kc_F10,
		kc_F11,
		kc_F12,
		kc_F13,
		kc_F14,
		kc_F15,
		kc_F16,
		kc_F17,
		kc_F18,
		kc_F19,
		kc_F20,
		kc_F21,
		kc_F22,
		kc_F23,
		kc_F24,
		kc_F25,
		kc_F26,
		kc_F27,
		kc_F28,
		kc_F29,
		kc_F30,
		kc_F31,
		kc_F32,

		// Misc
		kc_Delete = 127,
	}
	TKeyCode;

	typedef enum
	{
		//
		// Special modifier keys
		//
		km_Shift	= BIT(1),

		km_Control	= BIT(2),

		km_Alt		= BIT(3),
		km_Option	= BIT(3),		// Mac synonym for ALT key

		km_Clover	= BIT(4)		// Mac specific
	}
	TKeyModifiers;

	bool IsModifierPressed(TKeyModifiers Modifier);
	bool IsKeyPressed(TKeyCode KeyCode);
}

#endif // !vgui_Keyboard_h
