//
// ListBox.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "ListBox.h"

#include "ListBoxImp.h"

#include "vgui\Errors.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	ListBox::ListBox() : ListControl(TheFactory().MakeListBox())
	{
		// Already linked back to this DropDownList object by the base class,
		// so we don't need to call SetWindowLink here.
	}

	//
	// Multi-column support
	//

	bool ListBox::SetNumberOfColumns(uint nColumns)
	{
		return GetImp()->SetNumberOfColumns(nColumns);
	}

	uint ListBox::GetNumberOfColumns()
	{
		return GetImp()->GetNumberOfColumns();
	}
	
	void ListBox::ShowColumnHeaders(bool bShow)
	{
		GetImp()->ShowColumnHeaders(bShow);
	}

	bool ListBox::SetColumnName(uint iColumn, const String& ColumnName)
	{
		return GetImp()->SetColumnName(iColumn, ColumnName);
	}

	bool ListBox::SetColumnWidth(uint iColumn, uint WidthInPixels)
	{
		return GetImp()->SetColumnWidth(iColumn, WidthInPixels);
	}

	uint ListBox::GetColumnWidth(uint iColumn)
	{
		return GetImp()->GetColumnWidth(iColumn);
	}

	bool ListBox::AutoSizeColumn(uint iColumn)
	{
		return GetImp()->AutoSizeColumn(iColumn);
	}

	void ListBox::SetRowColour(uint Row, const Colour& RowColour)
	{
		GetImp()->SetRowColour(Row, RowColour);
	}

	void ListBox::UseDefaultRowColour(uint Row)
	{
		GetImp()->UseDefaultRowColour(Row);
	}

	void ListBox::SetCheckState(int iItem, ControlState ItemState)
	{
		GetImp()->SetCheckState(iItem, ItemState);
	}

	ControlState ListBox::GetCheckState(int iItem)
	{
		return GetImp()->GetCheckState(iItem);
	}

	bool ListBox::IsItemChecked(int iItem)
	{
		return (GetCheckState(iItem) == cs_Checked);
	}

	void ListBox::EnableCheckboxes(bool bEnable)
	{
		GetImp()->EnableCheckboxes(bEnable);
	}

	void ListBox::SetAllCheckBoxesOn()
	{
		int cItems = GetCount();

		for (int iItem = 0; iItem < cItems; iItem++)
		{
			SetCheckState(iItem, cs_Checked);
		}
	}
	
	void ListBox::SetAllCheckBoxesOff()
	{
		int cItems = GetCount();

		for (int iItem = 0; iItem < cItems; iItem++)
		{
			SetCheckState(iItem, cs_Unchecked);
		}
	}

};

