//
// ListBox.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_ListBox_h
#define vgui_ListBox_h

#include "vgui.h"

#include "ListControl.h"
#include "String.h"
#include "ResourceID.h"
#include "Controls.h"

namespace vgui
{
	class ListBox;
	class ListBoxImp;
	class Colour;

	class ListBox : public ListControl
	{
		public:
			ListBox();

			//
			// Multi-column support
			//

			bool SetNumberOfColumns(uint nColumns);
			uint GetNumberOfColumns();
			void ShowColumnHeaders(bool bShow);
			bool SetColumnName(uint iColumn, const String& ColumnName);
			bool SetColumnWidth(uint iColumn, uint WidthInPixels);
			uint GetColumnWidth(uint iColumn);
			bool AutoSizeColumn(uint iColumn);

			//
			// Redraw control
			//
			void SetRowColour(uint Row, const Colour& RowColour);
			void UseDefaultRowColour(uint Row);

			//
			// Checkbox control
			//
			void EnableCheckboxes(bool bEnable = true);
			void SetCheckState(int iItem, ControlState ItemState);
			ControlState GetCheckState(int iItem);
			bool IsItemChecked(int iItem);
			void SetAllCheckBoxesOn();
			void SetAllCheckBoxesOff();
		
		private:
			ListBoxImp* GetImp() const { return (ListBoxImp*) m_pWindowImp; }

		private:
			// Copying objects of this class is prohibited
			ListBox& operator=(const ListBox& rhs);
	};
};

#endif // !vgui_ListBox_h
