//
// ListControlImp.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_ListControlImp_h
#define vgui_ListControlImp_h

#include "vgui.h"

#include "Window.h"
#include "String.h"
#include "ResourceID.h"

#include "WindowImp_OS.h"

namespace vgui
{
	class ListControl;
	
	class ListControlImp : public WindowImp_OS
	{
		public:
			virtual void Clear() = 0;
			virtual int GetCount() const = 0;

			// Add and delete items
			virtual bool AddItem(const String& ItemName, 
								 int* piItem,
								 UserData TheUserData) = 0;

			virtual bool InsertItemAfter(int iAfterItem,
										 const String& ItemName, 
										 int* piItem,
										 UserData TheUserData) = 0;

			virtual bool InsertItemBefore(int iBeforeItem,
										  const String& ItemName, 
										  int* piItem,
										  UserData TheUserData) = 0;

			virtual bool DeleteItem(int iItem) = 0;

			virtual bool SetItemText(int iItem, const String& Text, int iColumn = 0) = 0;
			virtual bool SetItemData(int iItem, UserData TheUserData) = 0;

			// Find info about an item
			virtual bool GetItemText(int iItem, String* pItemName, int iColumn = 0) const = 0;
			virtual bool GetItemUserData(int iItem, UserData* pTheUserData) const = 0;

			// Change currently selected item
			virtual bool SetSelectedItem(int iItem) = 0;

			// Access currently selected item
			virtual bool GetSelectedItem(int* piSelectedItem) const = 0;

			// Find an item
			virtual bool FindItem(const String& ItemName, int* piFoundItem) = 0;

			// Sort control
			virtual void EnableSorting() = 0;
			virtual void DisableSorting() = 0;

			// Owner draw lists - refresh item metrics
			virtual void RemeasureItems() = 0;
			virtual void RemeasureItems(int NewHeight) = 0;
	};
};

#endif // !vgui_ListControlImp_h
