//
// MRUFileMenu.h - class for handling a MRU file list, and updating the
//				   application's menu accordingly.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_MRUFileMenu_h
#define vgui_MRUFileMenu_h

#include "MRUList.h"

#include "Application.h"
#include "MenuItem.h"
#include "Menu.h"
#include "MessageTarget.h"

namespace vgui
{
	class MRUFileMenu : public MessageTarget, public ShutdownHandler
	{
		public:
			static MRUFileMenu* Instance();

			// Set up the file menu
			void Initialise(MenuCommandID MRUMenuItem, uint cFiles);

			// Tell object that the specified file has just been used.
			void NotifyUsed(const vos::FileSpec& FS);

			// Shutdown handler - writes out the MRU to preferences on app exit
			virtual void OnShutdown(bool bNormalShutdown);

			// Read/write MRU list from preferences
			void ReadMRUFromPrefs();
			void WriteMRUToPrefs();

		public:
			//
			// Message Map
			//
			DECLARE_VGUI_MESSAGE_MAP();

			// Message handling overrides
			virtual bool DispatchCommand(int nCommand,
										 const MessageMapEntry *pEntry);

		private:
			void UpdateFileMenu();

			// Conversion from a file spec to a some menu item text suitable
			// for the platform.
			void ConvertFileSpecToMenuText(int iFile,
										   const vos::FileSpec& FS, 
										   vos::String *pMenuText);

		private:
			// The list of filenames
			MRUList<vos::FileSpec> m_Files;

			// Use Instance() to get the MRUFileMenu singleton.
			MRUFileMenu();

			static MRUFileMenu* m_pInstance;

			// The menu we are updating
			Menu m_FileMenu;

			// The ID of the first item for MRU files
			MenuCommandID m_MRUID;

			// The label provided for the MRU item in the original menu resource
			vos::String m_MRULabel;

			// Number of entries we have on the menu at the moment
			int m_cFileItems;
	};

}

#endif // !vgui_MRUFileMenu_h
