//
// Menu.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Menu_h
#define vgui_Menu_h

#include "vgui.h"

#include "MenuItem.h"

namespace vgui
{

#if defined VGUI_MSWINDOWS

	// MenuRef resolves to an HMENU for Win32.
	typedef HMENU MenuRef;

#elif defined VGUI_MACOS

	// MenuRef resolves to a ::MenuRef for MacOS.
	typedef ::MenuRef MenuRef;

#else

#error MenuRef needs porting

#endif

	/**************************************************************************

		class Menu

		Author:		Tim Browse

		Date:		29/8/00

		Purpose:	The Menu class is a simple veneer for dealing with menus
					and menu items (see also MenuItem class).

					The MenuRef type is aliases to whatever the current
					platform uses as a handle for menus.

	**************************************************************************/

	class Menu
	{
		public:
			Menu();
			Menu(MenuRef rMenu);

			void SetMenuRef(MenuRef rMenu);
			MenuRef GetMenuRef();

			// Find out how many items are in this menu
			uint GetItemCount();

			// Adding/deleting items
			bool InsertItem(const MenuItem& NewItem, uint nPos);
			bool AppendItem(const MenuItem& NewItem);
			bool DeleteItem(uint nPos);

			// Change an item
			void UpdateItem(uint nPos, const MenuItem& NewItem);
			void TickItem(MenuCommandID ID, bool bTick);

			// Retrieve item data
			bool GetItem(uint nPos, MenuItem* pItem);
			bool FindItem(MenuCommandID ID, uint* pPos);

			// Separators
			void InsertSeparator(uint nPos);
			void AppendSeparator();

			// Submenus
			bool GetSubMenu(uint nPos, Menu* pSubMenu);

		private:
			// Reference to the OS menu object
			MenuRef m_rMenu;
	};
};

#endif // !vgui_Menu_h
