//
// MessageMapMacros.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_MessageMapMacros_h
#define vgui_MessageMapMacros_h

namespace vgui
{
	class MessageMapEntry;
	class MessageMap;

	//
	// Macro to declare the message map in a class.
	//
#define DECLARE_VGUI_MESSAGE_MAP()											\
	private:																\
		static const vgui::MessageMapEntry _vgui_MessageMapEntries[];		\
	protected:																\
		static const vgui::MessageMap _vgui_MessageMap;						\
		virtual const vgui::MessageMap* GetMessageMap() const;



	//
	// Macros to begin and end the definition of a class's message map.
	//
#define BEGIN_VGUI_MESSAGE_MAP(theClass, baseClass)							\
		const vgui::MessageMap* theClass::GetMessageMap() const				\
			{ return &theClass::_vgui_MessageMap; }							\
		const vgui::MessageMap theClass::_vgui_MessageMap =					\
		{																	\
			&baseClass::_vgui_MessageMap,									\
			&theClass::_vgui_MessageMapEntries[0]							\
		};																	\
		const vgui::MessageMapEntry theClass::_vgui_MessageMapEntries[] =	\
		{


#define END_VGUI_MESSAGE_MAP()														\
			{vgui::mt_NONE, 0, 0, 0, (vgui::MessageTargetFn) NULL, MMFnSig_none }	\
		};

	//
	// Macros to define entries in a class's message map.
	//

#define ON_VGUI_COMMAND(nCommandID, CommandFn)								\
			{vgui::mt_COMMAND, nCommandID, 0, 0, (vgui::MessageTargetFn) CommandFn, MMFnSig_b_v},

#define ON_VGUI_REDRAW()								\
			{vgui::mt_REPAINT, 0, 0, 0, (vgui::MessageTargetFn) (bool (Window::*)(void))&OnRedraw, MMFnSig_b_v},


#define ON_VGUI_EBN_TEXTCHANGED(CtrlID, HandlerFn)								\
			{vgui::mt_EBN_TEXTCHANGED, 0, CtrlID, CtrlID, (vgui::MessageTargetFn) HandlerFn, MMFnSig_b_v},

#define ON_VGUI_BN_CLICKED(CtrlID, HandlerFn)								\
			{vgui::mt_BN_CLICKED, 0, CtrlID, CtrlID, reinterpret_cast<vgui::MessageTargetFn>(HandlerFn), MMFnSig_b_v},

};

#endif // !vgui_MessageMapMacros_h
