//
// MessageTarget.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_MessageTarget_h
#define vgui_MessageTarget_h

#include "vgui.h"

#include "Messages.h"
#include "ControlID.h"

#include <list>

#define DECLARE_VGUI_MESSAGE_MAP()											\
	private:																\
		static vgui::MessageMapEntry _vgui_MessageMapEntries[];		\
	protected:																\
		static const vgui::MessageMap _vgui_MessageMap;						\
		virtual const vgui::MessageMap* GetMessageMap() const;


namespace vgui
{
	class MessageMap;
	class MessageMapEntry;
	class MessageParams;
	class MessageTarget;

	typedef std::list<MessageTarget*> DynamicMessageMaps;

	class MessageTarget
	{
		public:
			//
			// Constructor/Destructor
			//

			MessageTarget();
			virtual ~MessageTarget();

		public:
			//
			// Message Map
			//
			DECLARE_VGUI_MESSAGE_MAP();

		public:
			//
			// Message handling
			//

			virtual bool OnCommand(int nCommand);

			virtual bool DispatchCommand(int nCommand,
										 const MessageMapEntry *pEntry);

			// No need to over-ride message handling logic.
			bool OnMessage(TMessageType MsgType,
						   int nMsg,
						   int nCtrlID,
						   MessageParams* pParams = NULL);

			bool FindMessageHandler(TMessageType MsgType,
								    int nMsg,
								    int nCtrlID, 
								    const MessageMapEntry*& pFoundEntry);

			bool CallMessageHandler(const MessageMapEntry* pEntry,
									TMessageType MsgType,
									int nMsg,
									int nCtrlID,
									MessageParams* pParams = NULL);

			// Dynamically extending message maps
			void AddMessageTarget(MessageTarget* pMessageTarget);
			void RemoveMessageTarget(MessageTarget* pMessageTarget);

		protected:
			//
			// Routines to find matches in the message maps.
			//
			bool FindCommandEntry(const MessageMapEntry *pEntries,
								  int nCommand,
								  const MessageMapEntry*& pFoundEntry);


			bool FindMatchingEntry(const MessageMapEntry *pEntries,
								   TMessageType MsgType,
								   int nMsg,
								   int nCtrlID, 
								   const MessageMapEntry*& pFoundEntry);

			// Generic message processing
			bool OnMessage(const MessageMap* pMap,
						   TMessageType MsgType,
						   int nMsg,
						   int nCtrlID,
						   MessageParams* pParams);

			bool OnCommand(const MessageMap* pMap, int nCommand);
			
		private:
			// Extra message maps to check before checking this
			// object's message map.
			DynamicMessageMaps m_DynamicMaps;
	};

};

#endif // !vgui_MessageTarget_h


