//
// MsgDialog.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_MsgDialog_h
#define vgui_MsgDialog_h

#include "vGUI.h"

#include "Dialog.h"
#include "Rect.h"

namespace vgui
{
	//
	// The dialog used to show a question
	//

	class MsgDialog : public Dialog
	{
		public:
			MsgDialog(const DialogResourceID& DialogID,
					  Window* pParent,
					  ControlID MessageBox);

			virtual ~MsgDialog();

			void SetTitle(const String& Title)
			{
				m_Title = Title;
			}

			void SetMessage(const String& MessageText)
			{
				m_Message = MessageText;
			}

			// Over-ride this function if you need to reposition controls
			virtual void RepositionControls(int *pDeltaX, int* pDeltaY) {}

			// Over-ride redraw
			virtual bool OnRedraw();

			// Call this to change size of dialog.
			// Over-ride if you need finer handling.
			virtual void ResizeDialog(int DeltaX, int DeltaY);

			// Over-ride this to execute code you would normally put in
			// OnInitDialog().
			virtual void InitTheDialog() {}

			// Call this to adjust the size of the message area
			// (before the dialog is displayed)
			virtual void AdjustMessageArea(int DeltaX, int DeltaY);

		private:
			// This is private because we don't want derived classes to
			// over-ride it; they should over-ride InitTheDialog() instead.
			virtual void OnInitDialog();

		protected:
			void ResizeMessage();

		protected:
			// The area covered by the message
			Rect m_MessageArea;

		protected:
			// The message box control ID and control object
			ControlID m_MessageBoxID;
			Window	  m_MessageBox;

			// Title of the dialog
			String m_Title;

			// The message itself
			String m_Message;
	};
};

#endif // !vgui_MsgDialog_h
