//
// OwnerDrawListBox.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "OwnerDrawListBox.h"

namespace vgui
{
	
	/**************************************************************************

	>	OwnerDrawListBox::OwnerDrawListBox()

		Author:		Tim Browse
		Date:		07/03/2001

		Purpose:	Constuctor - it makes sure that the owner draw functionality
					is exposed to the corresponding ListControlImp-based object.

	**************************************************************************/

	OwnerDrawListBox::OwnerDrawListBox()
	{
		// Set up accessible link to this object - this is slightly weird, because
		// we end up setting a pointer to point to ourselves, but it is the
		// cleanest way of allowing the ListControlImp object to hook up
		// owner draw events.
		m_pOwnerDrawHandler = this;
	}

	
	/**************************************************************************

	>	bool OwnerDrawListBox::OnMeasureItem(int iItem, 
											 UserData TheUserData, 
											 uint* pItemHeight)

		Author:		Tim Browse
		Date:		07/03/2001
		Inputs:		iItem - index of the item to measure
					TheUserData - whatever data has been attached to the item.
		Outputs:	pItemHeight - the desired height of the item.
		Returns:	true => custom size was specified
					false => no size set up - caller should use default size.

		Purpose:	Hook to allow a class to specify the height of list items
					(on a global or item by item basis).

					If the class needs to specify custom sizes for list items,
					it should over-ride this function.

	**************************************************************************/

	bool OwnerDrawListBox::OnMeasureItem(int iItem, 
									     UserData TheUserData, 
									     uint* pItemHeight)
	{
		// By default, we don't do special sized items - it's up to the client
		// to over-ride this function if they want that.
		return false;
	}



	/**************************************************************************

	>	bool OwnerDrawListBox::OnDrawItem(GC* pGC, 
										  int iItem,
										  UserData TheUserData,
										  const Rect& rcItem,
										  int OwnerDrawItemState)

		Author:		Tim Browse
		Date:		07/03/2001
		Inputs:		pGC - the GC to draw into, to render this item.
					iItem - index of the item to measure
					TheUserData - whatever data has been attached to the item.
					rcItem - the rectangle occupied by this item.
					OwnerDrawItemState - state of this item - bit values as 
										 follows:

											OwnerDrawItemState_Selected
											OwnerDrawItemState_HasFocus
											OwnerDrawItemState_Disabled

		Returns:	true => item was rendered; no further drawing needed.
					false => item not rendered; use default rendering, OR
							 item was rendered; now do default rendering.

							 (e.g. on Windows, the default rendering shows
								   the correct focus rectangle).

		Purpose:	Allows a class to hook into list redrawing, to enable it
					to provide custom rendering for list items.

					If the class needs to do custom list item rendering, it
					should over-ride this function.

	**************************************************************************/

	bool OwnerDrawListBox::OnDrawItem(GC* pGC, 
									  int iItem,
									  UserData TheUserData,
									  const Rect& rcItem,
									  int OwnerDrawItemState)
	{
		// By default, we don't do custom rendering - it's up to the client
		// to over-ride this function if they want that.
		return false;
	}
}

