//
// OwnerDrawListControl.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_OwnerDrawListControl_h
#define vgui_OwnerDrawListControl_h

#include "vgui.h"

#include "GC.h"

namespace vgui
{
	//
	// Enum bitfield constants used by OwnerDrawListControl interface
	// to specify the state of the item being drawn.
	//
	typedef enum
	{
		OwnerDrawItemState_Selected = BIT(0),
		OwnerDrawItemState_HasFocus = BIT(1),
		OwnerDrawItemState_Disabled = BIT(2),
	}
	TOwnerDrawItemState;

	
	/**************************************************************************

	>	class OwnerDrawListControl

		Author:		Tim Browse

		Date:		07/03/2001

		Purpose:	Provide a pure interface to use as a mix-in class for
					ListControl derived objects that want to support 
					owner-draw items.

					For example, the ListBox class is customised as follows:

						class OwnerDrawListBox : public ListBox,
												 public OwnerDrawListControl

					so it has the interface of a ListBox, plus the interface
					for handling custom sizing/drawing of items in the list.

					Basically, the OnMeasureItem and OnDrawItem functions
					will be called to determine the size and appearance of
					owner draw list controls (whatever type of list controls
					they may be).

					Therefore, when deriving a new class from a class such
					as OwnerDrawListBox or OwnerDrawDropDownList, the new
					class should over-ride one or both of these functions
					to create the desired effect.

	**************************************************************************/

	class OwnerDrawListControl
	{
		public:
			virtual bool OnMeasureItem(int iItem, 
									   UserData TheUserData, 
									   uint* pItemHeight) = 0;

			virtual bool OnDrawItem(GC* pGC, 
									int iItem,
									UserData TheUserData,
									const Rect& rcItem,
									int OwnerDrawItemState) = 0;
	};
};

#endif // !vgui_OwnerDrawListControl_h
