//
// ProgressDialog.h
//

#ifndef inc_ProgressDialog_h
#define inc_ProgressDialog_h

#include "Dialog.h"
#include "ProgressBar.h"
#include "Button.h"
#include "Application.h"

#include "JobWorker.h"
#include "JobController.h"

namespace vgui
{
	/**************************************************************************

		class ProgressDialog : public vgui::Dialog,
							   public JobController

		Author:		Tim Browse

		Date:		2001/10/25

		Purpose:	Display a progress dialog while some work is being done.

					The client provides a JobWorker object that does
					the actual work.  

	**************************************************************************/

	class ProgressDialog : public Dialog,
						   public JobController
	{
		public:
			// Constructor
			ProgressDialog(JobWorker* pWorker,
						   const vos::String& strProgressMessage,
						   Window* pParent = NULL);

			// Display/use the progress dialog
			bool ShowProgress();
			bool ShowProgressWithPercentage();
			bool ShowProgressWithoutCancel();

			// Dialog init/message handling
			void OnInitDialog();
			virtual bool OnTimer(TimerID ID);
			virtual void OnCancel();

			// Don't call this - use ShowProgressXXX() functions
			ControlID DoModal();

			//
			// JobController interface...
			//

			// Update the progress bar
			void UpdateJobProgressDisplay(uint PercentComplete);

			// Find out if the user has cancelled the operation yet.
			bool IsJobCancelled() const;

		private:
			// Central function for changing slider position
			void ProgressDialog::SetPosition(int PercentComplete);

			// Central function for doing the work and displaying the dialog
			bool DoTheWork(uint msInitialDelay = 300);

		private:
			// The progress bar control
			ProgressBar m_ProgressBar;

			// The cancel button
			Button m_Cancel;

			// The text to display as the progress message
			vos::String m_strProgressMessage;

			// The worker object
			JobWorker* m_pJobWorker;

			// Timer ID for our timer events
			TimerID m_TimerID;

			// Flag to remember whether 'Cancel' has been pressed yet.
			bool m_bCancelled;

			// Flag to indicate whether this is a percentage dialog, 
			// or an 'indeterminate' one.
			bool m_bShowPercentage;

			// Flag to indicate whether to have a cancel button or not.
			bool m_bShowCancelButton;

			// How far we are through the job.
			int m_PercentComplete;

			// Has the dialog been initialised yet?
			bool m_bDialogInitialised;
	};
};


#endif //! inc_ProgressDialog_h
