//
// Question.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Question_h
#define vgui_Question_h

#include "ResourceID.h"
#include "ControlID.h"

namespace vgui
{
	class QuestionDialog;

	/**************************************************************************
	
	>	class Question
	
		Author:		Tim Browse
		Date:		7/5/2002
	
		Purpose:	Provide a simple (but functional) system for asking the
					user questions.  The caller is in complete control of
					how many buttons (choices) are displayed to the user, and
					how they are labelled.

					Call Initialise() when your application starts up, and
					then call Ask() whenever you want to ask the user 
					a question.

	**************************************************************************/
	
	class Question
	{
		public:
			// This function must be called before calling Ask()
			static void Initialise(const DialogResourceID& QuestionDialogID,
								   ControlID QuestionTextControl,
								   ControlID QuestionDefButtonControl,
								   ControlID QuestionButtonControl,
								   ControlID QuestionDontAskMeAgainControl = NOCTL);

			Question(const StringResourceID& Title,
					 const StringResourceID& Question,
					 Window* pParent = NULL);

			Question(const char* szTitle,
					 const char* szQuestion,
					 Window* pParent = NULL);

			~Question();

			void SetCheckBoxPreference(const char* szPreferenceName);
			void EnableCheckBox();

			bool AskUserNextTime();

		public:
			// Call one of these Ask() functions to ask the user a question.
			StringResourceID Ask(const StringResourceID Buttons[]);
			int Ask(const char* szButtons[]);
			bool AskYesNo();
			bool AskOKCancel();

			// Used by QuestionDialog
			static vos::String MakeButtonName(const vos::String& ButtonText);

		private:
			void GetQuestionOptions(bool *pbShowCheckBox, 
								    bool *pbAskUser, 
								    int  *piLastChoice);

			vos::String GetButtonPrefName();

		private:
			// The dialog that does the work
			QuestionDialog* m_pDialog;

			// Name of the preference for this question (if any)
			vos::String m_PrefName;

			// Show the "Don't ask again" checkbox?
			bool m_bShowCheckBox;

		private:
			// Static variables
			static DialogResourceID s_QuestionDialogID;
			static ControlID s_QuestionTextControl;
			static ControlID s_QuestionDefButtonControl;
			static ControlID s_QuestionButtonControl;
			static ControlID s_QuestionDontAskMeAgainCheckBox;
			friend class QuestionDialog;
	};
};

#endif // !vgui_Question_h
