//
// QuestionDialog.h
//

#ifndef vgui_QuestionDialog_h
#define vgui_QuestionDialog_h

#include "MsgDialog.h"
#include "CheckBox.h"

namespace vgui
{
	class Button;
	
	/**************************************************************************
	
	>	class QuestionDialog : public MsgDialog
	
		Author:		Tim Browse
		Date:		7/5/2002
	
		Purpose:	Provide a simple dialog class for asking the user
					questions.

					NB. You can use this class if you want, but it is easier
						to use the Question class, as it is simpler.
	
	**************************************************************************/
	
	class QuestionDialog : public MsgDialog
	{
		public:
			DECLARE_VGUI_MESSAGE_MAP();

		public:
			QuestionDialog(const StringResourceID& Title,
						   const StringResourceID& Question,
						   Window* pParent);

			QuestionDialog(const char *szTitle,
						   const char *szQuestion,
						   Window* pParent);

			~QuestionDialog();

			void SetButtons(const StringResourceID  Buttons[]);
			void SetButtons(const char *szButtons[]);

			void ShowCheckBox();

			bool AskUserNextTime();

			int FindButton(const vos::String& ButtonName);

		public:
			// Message handlers
			virtual void InitTheDialog();

		public:
			// Used to move buttons around (when dialog is resized to fit
			// the question text in)
			void RepositionControls(int* pDeltaX, int* pDeltaY);

		protected:
			void CreateButtons();
			void ResizeMessage();

			bool OnButtonClicked(TMessageType MsgType, int nMsg, int ButtonPressed);

		protected:
			// The question and title of the question dialog.
			String m_Question;
			String m_Title;

			// The array of button objects, IDs and strings
			Button**	m_pButtons;
			ControlID*	m_pButtonIDs;
			String*		m_pButtonStrings;

			// Number of buttons in the dialog
			uint m_cButtons;

			Window m_QuestionMessage;

			// The "don't ask me again" checkbox.
			CheckBox m_CheckBox;
			
			// Flag to indicate if we should display a check box
			// under the alert text, saying "Don't ask me about this again."
			bool m_bShowDontAskMeAgainCheckBox;

			// Flag to indicate what the user decided on the "Don't ask me
			// about this me again" option
			bool m_bAskUserNextTime;

	};
};

#endif // !vgui_QuestionDialog_h
