//
// RadioGroup.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "RadioGroup.h"

#include "Errors.h"

#ifdef VGUI_MSWINDOWS
#include "Win32\Win32_WindowImp.h"
#endif

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	RadioGroup::RadioGroup(Window *pParent) : m_pWindow(pParent)
	{
	}

	RadioGroup::RadioGroup(Window *pParent, 
						   ControlID *pControlIDs) : m_pWindow(pParent)
	{
		AddIDs(pControlIDs);
	}

	// Add IDs to the group
	int RadioGroup::AddID(ControlID ID)
	{
		m_IDs.push_back(ID);
		return m_IDs.size();
	}

	int RadioGroup::AddIDs(ControlID *pControlIDs)
	{
		// Add all IDs until we find NOCTL.
		while (*pControlIDs != NOCTL)
		{
			m_IDs.push_back(*pControlIDs);

			pControlIDs++;
		}

		return m_IDs.size();
	}

	// Read/write
	RadioGroup::operator ControlID() const
	{
		return GetState();
	}

	RadioGroup& RadioGroup::operator=(ControlID ID)
	{
		SetState(ID);
		return *this;
	}

	void RadioGroup::SetState(ControlID ID)
	{
#if defined VGUI_MSWINDOWS
		Win32_WindowImp * pWindowImp = Win32_WindowImp::GetImp(m_pWindow);
		if (pWindowImp == NULL)
		{
			COMPLAIN("Unable to access window object.");
			return;
		}

		HWND hParent = pWindowImp->GetHWND();

		// Get the control window
		HWND hControl = ::GetDlgItem(hParent, ID);

		if (hControl != NULL)
		{
			::SendMessage(hControl, BM_SETCHECK, BST_CHECKED, 0);
		}
		else
		{
			COMPLAIN("Unable to find control in RadioGroup::SetState().");
		}
#elif defined VGUI_MACOS		
		COMPLAIN("#RadioGroup::SetState() needs porting.");
#else
#error RadioGroup::SetState() needs porting.
#endif
	}

	ControlID RadioGroup::GetState() const
	{
#if defined VGUI_MSWINDOWS
		Win32_WindowImp * pWindowImp = Win32_WindowImp::GetImp(m_pWindow);
		if (pWindowImp == NULL)
		{
			COMPLAIN("Unable to access window object.");
			return NOCTL;
		}

		HWND hParent = pWindowImp->GetHWND();

		ControlIDs::const_iterator it = m_IDs.begin();

		// Search for radio button that is selected
		while (it != m_IDs.end())
		{
			// Get the control window
			HWND hControl = ::GetDlgItem(hParent, *it);

			if (hControl != NULL)
			{
				if (::SendMessage(hControl, BM_GETCHECK, 0, 0) == BST_CHECKED)
				{
					// Found the selected icon
					return *it;
				}
			}
			else
			{
				COMPLAIN("Unable to find control in RadioGroup::GetState().");
				return NOCTL;
			}

			// Try next ID
			++it;
		}

		// No item is selected
		return NOCTL;
#elif defined VGUI_MACOS		
		COMPLAIN("#RadioGroup::SetState() needs porting.");
		return NOCTL;
#else
#error RadioGroup::GetState() needs porting.
#endif
	}
};
