//
// ResourceFile.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "ResourceFile.h"

#ifdef VGUI_MSWINDOWS
#include "Win32\Win32_Headers.h"
#elif defined VGUI_MACOS
#include ":MacOS:MacOS_Headers.h"
#endif

#include "Errors.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	// Constructors/Destructor
	ResourceFile::ResourceFile()
	{
	}

	ResourceFile::~ResourceFile()
	{
	}

	// Opening and closing files
	Error ResourceFile::Open(const RawDataResourceID& FileID, vos::FileMode Mode)
	{
#ifdef VGUI_MSWINDOWS
		// Open the Win32 resources as raw data
		HRSRC hResInfo = ::FindResource(NULL, FileID.GetID(), "TEXT");
		if (hResInfo != NULL)
		{
			// Load the resource
			HGLOBAL hResData = ::LoadResource(NULL, hResInfo);

			if (hResData != NULL)
			{
				// Lock the resource data for use by the resource file
				byte* pData = (byte*) ::LockResource(hResData);

				if (pData != NULL)
				{
					// Ok, we have some data, so use the base class to open the file with it
					return MemoryFile::Open(pData, 
											::SizeofResource(NULL, hResInfo), 
											Mode);
				}
			}
		}

#elif defined VGUI_MACOS
		// Open the resource
		::Handle hResource = ::GetResource('vGUI', FileID.GetID());
		if((hResource != NULL) && (::ResError() == ::noErr))
		{
			::HLock(hResource);
			// Ok, we have some data, so use the base class to open the file with it
			return MemoryFile::Open((unsigned char *)*hResource, 
									(unsigned int)::GetHandleSize(hResource), 
									Mode);
		}
#endif

		// An error must have occured
		return ERROR(vos::Err_File_OpenFailed, "Unable to open resource-based file.");
	}

	void ResourceFile::Close()
	{
#ifdef VGUI_MSWINDOWS
		// Currently nothing needs to be done - Win32 resources are automatically 
		// unloaded on program exit.
#endif
	}
};


