//
// ResourceID.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "ResourceID.h"

#include "Application.h"

#include "Icon.h"

#ifdef VGUI_MSWINDOWS

#include "Win32\Win32_ApplicationImp.h"
#include "Win32\Win32_Headers.h"

#endif

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
#if defined VGUI_MSWINDOWS

	DialogResourceID DialogResourceID::s_DynamicDialog(0);

	bool IconResourceID::Load(Icon* pTheIcon,
							  int DesiredWidth, 
							  int DesiredHeight) const
	{
		UINT nID = (UINT) GetID();

		// Fail if it's a null ID.
		if (nID == 0)
			return false;

		// Load the icon
		HANDLE hIcon = ::LoadImage(GetWin32App()->GetInstance(),
								   MAKEINTRESOURCE(nID), 
								   IMAGE_ICON,
								   DesiredWidth, DesiredHeight,
								   0);

		if (hIcon == NULL)
		{
			// Load failed
			DWORD Error = GetLastError();
 			vguiERROR();
			return false;
		}

		// Install handle into icon object
		pTheIcon->m_hIcon = (HICON) hIcon;

		// Load icon succeeded
		return true;
	}

#elif defined VGUI_MACOS


	// Static object used to instantiate dynamic dialogs.
	// (Dynamic dialogs are empty and must be filled in/sized
	// by the client).
	DialogResourceID DialogResourceID::s_DynamicDialog(-1);

	bool IconResourceID::Load(Icon* pTheIcon,
							  int DesiredWidth, 
							  int DesiredHeight) const
	{
		::Handle hIconFamily;
		
		::OSErr Err = ::GetIconSuite(&hIconFamily, GetID(), ::kSelectorAllAvailableData);

		if(::MemError() || ::ResError() || (hIconFamily == NULL))
		{
			// Load failed
 			vguiERROR();
			return false;
		}

		// Install handle into icon object
		pTheIcon->m_hIconFamily = hIconFamily;

		// Load icon succeeded
		return true;
	}

#endif

};
