//
// ResourceID.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_ResourceID_h
#define vgui_ResourceID_h

#include "vgui.h"

#include "String.h"
#include "vos\ResourceID.h"

namespace vgui
{
	class Icon;

	typedef vos::SimpleResourceID SimpleResourceID;
	typedef vos::RawDataResourceID RawDataResourceID;
	typedef vos::StringResourceID StringResourceID;

	// Enum to specify type of a ResourceID object
	// (extends the ResType_XXX enums in vOS)
	enum
	{
		ResType_Dialog = vos::ResourceID::ResType_VOS_Last,
		ResType_Menu,
		ResType_Cursor,
		ResType_Bitmap,
		ResType_Icon,
		ResType_Accelerator,
	};

	class DialogResourceID : public vos::ResourceID
	{
	public:
		//
		// Constructor
		//
		DialogResourceID() : ResourceID(ResType_Dialog) {}
		DialogResourceID(int ID) : ResourceID(ResType_Dialog, ID) {}

		bool operator==(const DialogResourceID& rhs) const
		{
			return rhs.GetID() == GetID();
		}

		bool operator!=(const DialogResourceID& rhs) const
		{
			return rhs.GetID() != GetID();
		}

		// Special ID for dynamically constructed dialogs
		static DialogResourceID s_DynamicDialog;
	};


	class MenuResourceID : public vos::ResourceID
	{
	public:
		//
		// Constructor
		//
		MenuResourceID() : ResourceID(ResType_Menu) {}
		MenuResourceID(int ID) : ResourceID(ResType_Menu, ID) {}
	};

	class CursorResourceID : public vos::ResourceID
	{
	public:
		//
		// Constructor
		//
		CursorResourceID() : ResourceID(ResType_Cursor) {}
		CursorResourceID(int ID) : ResourceID(ResType_Cursor, ID) {}
	};

	class BitmapResourceID : public vos::ResourceID
	{
	public:
		//
		// Constructor
		//
		BitmapResourceID() : ResourceID(ResType_Bitmap) {}
		BitmapResourceID(int ID) : ResourceID(ResType_Bitmap, ID) {}
	};

	class IconResourceID : public vos::ResourceID
	{
	public:
		//
		// Constructor
		//
		IconResourceID() : ResourceID(ResType_Icon) {}
		IconResourceID(int ID) : ResourceID(ResType_Icon, ID) {}

		//
		// Resource loading
		//

		bool Load(Icon* pTheIcon,
				  int DesiredWidth = 0, 
				  int DesiredHeight = 0) const;
	};

	class AcceleratorResourceID : public vos::ResourceID
	{
	public:
		//
		// Constructor
		//
		AcceleratorResourceID() : ResourceID(ResType_Accelerator) {}
		AcceleratorResourceID(int ID) : ResourceID(ResType_Accelerator, ID) {}
	};

};

#endif // !vgui_ResourceID_h


