//
// SaveDialog.h - dialog for specifying where to save a file.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_SaveDialog_h
#define vgui_SaveDialog_h

#include "vgui.h"
#include "String.h"
#include "Dialog.h"

#include "vOS\FileSpec.h"

#include "DocumentClass.h"

#include "FileDialogParams.h"

#define kFilterBufSize (128)

namespace vgui
{
	using vos::FileSpec;

	//
	// Concepts that vary:
	//
	//
	/*
		Input:

			Dialog title
			Initial folder
			Leaf name
			File Filters - list of extensions/descriptions
			Flags:
				Multiple selection

		Output:

			Success/failure flag
			Pathname of the file
	*/

	//
	// Flags to control behaviour of the save dialog
	//
	typedef enum
	{
		// Null flags - normal behaviour
		sdf_Normal				= 0,

		//
		// This flag specifies that overwriting a file must be confirmed.
		//
		sdf_ConfirmOverwrite	= BIT(0),
	}
	SaveDialogFlags;

	//
	// NB. Because of variation of platform implementations, SaveDialog is
	//     a self contained class, rather than being derived from Dialog.
	//
	class SaveDialog
	{
		public:
			SaveDialog(FileDialogParams* pParams,
					   const Window* pParent = NULL);

			~SaveDialog();

			bool GetFilename(FileSpec* pSaveFilename);

		private:
			FileDialogParams* m_pParams;
			const Window* m_pParent;
	};

};

#endif // !vgui_SaveDialog_h
