//
// Shell.cpp - the Shell class
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Shell.h"

#include "vos\FileSpec.h"
#include "vos\Errors.h"
#include "vos\File.h"

#include "vgui\Msgs.h"


#ifdef VGUI_MSWINDOWS
#include "shellapi.h"
#endif


namespace vgui
{
	Error Shell::OpenFolder(const vos::FileSpec& FolderName)
	{
		// Check this is a folder
		if (FolderName.GetFileType() != vos::FileType_Folder)
		{
			// Not a folder, so let's not open it.
			return ERROR(Err_BadParam, msgShell_NoSuchFolder);
		}

#ifdef VGUI_MSWINDOWS

		//
		// NASTY HACK WARNING
		//
		// Ok, ShellExecute() can be a bit dumb - if you ask it to "open" the
		// folder "C:\Test", and there happens to exist an EXE with the name
		// "C:\Test.exe", it will actually run the EXE instead of opening the
		// folder.
		//
		// I have got around this by using an old hack from my DOS throwback days,
		// which is the knowledge that folders don't have a file extension (you
		// used to be able to do "dir *." to see all the folders.
		//
		// Now, you can add 'extensions' to folders in Windows, but they just seem
		// to end up as part of the filename, not the extension.
		//
		// Therefore when opening a folder, we add a single '.' to the end of
		// the pathname.  This seems sufficient to fool Windows into opening
		// the folder correctly.
		//
		// This is true even when the names are, e.g. "Test.1" and "Test.1.exe", i.e.
		// even if the folder seems to have an 'extension' (which as described,
		// it doesn't really).
		//
		// Anyway, that's the reason for this lovely hack :)
		//
		vos::String strFolderName(FolderName.GetString());
		strFolderName += ".";

		// Ok, open the folder.
		int iResult = (int) ::ShellExecute(NULL, "open", strFolderName.c_str(), NULL, NULL, SW_SHOW);

		// If the result is >32 then it worked (great logic, huh?)
		if (iResult > 32)
		{
			return VNOERROR;
		}

		// Ok, it failed, let the caller know why, to the best of our abilities...
		switch (iResult)
		{
			case 0:
			case SE_ERR_OOM:
				// The operating system is out of memory or resources. 
				return ERROR_NOMEMORY();

			case ERROR_FILE_NOT_FOUND:
			case ERROR_PATH_NOT_FOUND:
				// The specified file/path was not found. 
				return ERROR(vos::Err_File_NotFound, msgShell_NoSuchFolder);

			case SE_ERR_ACCESSDENIED:
			case SE_ERR_SHARE:
				// The operating system denied access to the specified file.  
				return ERROR(vos::Err_File_AccessDenied, msgFile_Access_Fail);

			default:
				// Any other errors don't make sense in this context.
				vguiERROR();
				return ERROR(Err_GenericError, msgShell_OpenFolderFailed);
		}
#else
		// TODO: Shell::OpenFolder() needs porting...
		return VNOERROR;
#endif
	}
};
