//
// TabControl.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_TabControl_h
#define vgui_TabControl_h

#include "Window.h"
#include "String.h"

namespace vgui
{
	// Different GUIs have different ways of dealing with tabs in
	// a tab control - some use control IDs, others use dialog IDs, etc.
#ifdef WIN32
	typedef DialogResourceID TabResourceID;
#endif

	class TabControlImp;

	/**************************************************************************
	
	>	class TabControl : public Window
	
		Author:		Tim Browse
		Date:		21/6/2002
	
		Purpose:	Interface for controlling a 'tabbed' control in a 
					Window/Dialog.

					Each tab in a tabbed control is built from/specified by
					a TabResourceID, which changes from platform to 
					platform.  For example, under Windows, this is a dialog
					ID, and the tab contents are build from the dialog template.
					Under Mac OS/Carbon, it is a control ID, as the resource
					editor allows the tabs to be edited as part of the
					whole dialog.

					All messages for the controls in this dialog are routed
					to the parent dialog, so you must ensure that control
					IDs in the tabs do not clash, otherwise you will not
					be able to respond to control messages correctly.
	
	  
		Win32:		When creating a dialog to use as a tab in Visual Studio, set 
					the style to be 'Child' and the Border to be 'None'.  
					Also, enable the 'Control' flag in the 'More Styles' tab.

	**************************************************************************/
	
	class TabControl : public Window
	{
		public:
			TabControl();

			// Add a tab to the tab control
			bool AddTab(const TabResourceID& TabID, 
						const vos::String& TabName);
			bool AddTab(const TabResourceID& TabID, 
						const vgui::StringResourceID& TabName);

			// Select a particular tab
			bool SelectTab(const TabResourceID& TabID);

			// Find out which tab is currently chosen.
			TabResourceID GetSelectedTab() const;

			// Specifying NOCTL will result in a unique control ID being chosen for you.
			bool Create(Window* pParent,
						const Rect& Position,
						ControlID ID = NOCTL);

			virtual bool OnResize(int NewWidth, int NewHeight);

		private:
			TabControlImp* GetImp() const { return (TabControlImp*) m_pWindowImp; }

		private:
			// Copying objects of this class is prohibited
			TabControl& operator=(const TabControl& rhs);
	};
};

#endif // !vgui_TabControl_h
