//
// WaitCursor.h - the WaitCursor class
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_WaitCursor_h
#define vgui_WaitCursor_h

#include "vGUI.h"

namespace vgui
{
	/**************************************************************************
	
		class WaitCursor
	
		Author:		Tim Browse
	
		Date:		2001/10/28
	
		Purpose:	Display a wait (hourglass) cursor during a long job to
					let the user know the program is busy.

					To display an hourglass, just create a WaitCursor object,
					and when it is destructed, then the hourglass will go away.

					You can force the hourglass to go away on demand using
					the Stop() function.
	
	**************************************************************************/
	
	class WaitCursor
	{
		public:
			WaitCursor();
			~WaitCursor();

			void Stop();

			// For use by vGUI framework...
			static bool IsActive();

		private:
			void AddWaitCursor();
			void RemoveWaitCursor();

		private:
			// true if the wait cursor object is still effective (i.e.
			// Stop has not been called).
			bool m_bActive;

			// Wait cursor semaphore
			static int s_cWaitCursors;
	};
};

#endif // !vgui_WaitCursor_h
