//
// WindowImp.h - Window Implementation Interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_WindowImp_h
#define vgui_WindowImp_h

#include "vgui.h"

#include "Window.h"

namespace vgui
{
	class WindowImp
	{
		public:

			//
			// Constructor/Destructor
			//

			WindowImp();
			virtual ~WindowImp() {}

			//
			// Link back to Window object
			void SetWindowLink(Window *pWindow);

			Window* GetWindowLink();

			//
			//
			// Window creation/destruction
			//
			virtual bool Create(Window *pWindow,
								Window* pParent,
								TWindowStyle Style, 
								const StringResourceID* prWindowTitle) = 0;

			virtual bool Create(Window *pWindow,
								Window* pParent,
								TWindowStyle Style, 
								const String* psWindowTitle) = 0;

			virtual void Destroy() = 0;

			virtual void CentreWindow() = 0;

			virtual void GetPosition(Rect* pWindowPosition) = 0;

			virtual void Move(const Rect& NewPosition, bool bForceRedraw) = 0;
			virtual void SetSafePosition(const Rect& NewPosition, bool bForceRedraw) = 0;

			virtual void SetClientArea(const Rect& NewClientArea) = 0;

			virtual void Resize(uint NewWidth, uint NewHeight) = 0;

			virtual void SetWorkArea(const Rect& WorkArea) = 0;
			virtual void GetWorkArea(Rect* pWorkArea) = 0;

			virtual void EnableFloatingBehaviour(bool bFloat) = 0;

			virtual bool SetText(const String& Text) = 0;
			virtual bool GetText(String& Text) = 0;

			virtual void SetFocus() = 0;
			virtual bool HasFocus() = 0;

			virtual bool CaptureMouse() = 0;
			virtual void ReleaseMouse() = 0;
			
			virtual WindowHandle GetWindowHandle() const = 0;

			virtual void ShowScrollBar(TScrollBar) = 0;
			virtual void HideScrollBar(TScrollBar) = 0;

			virtual void EnableScrollBar(TScrollBar Bar, bool bEnable) = 0;

			virtual bool IsScrollBarVisible(TScrollBar Bar) = 0;

			virtual int GetScrollPos(TScrollBar Bar) = 0;
			virtual void SetScrollPos(TScrollBar Bar, int Pos) = 0;

			virtual TWindowPosture GetPosture() = 0;
			virtual void SetPosture(TWindowPosture Posture) = 0;

			//
			// Window manipulation
			//
			virtual void ShowWindow(TShowWindow Command) = 0;
			virtual void UpdateWindow() = 0;

			// Redraw lock/unlock
			virtual void LockRedraw() = 0;
			virtual void UnlockRedraw() = 0;

			//
			// Get information
			//

			virtual void GetArea(Rect* pArea) = 0;
			virtual void GetClientArea(Rect* pClientArea) = 0;

			virtual ControlID GetControlID() = 0;

			virtual ControlID FindUniqueControlID() = 0;

			virtual Font* GetFont() = 0;


			//
			// Attaching to existing windows - use with care
			//
			virtual void Attach(Window *pParent,
								ControlID ID) = 0;

			virtual void AttachByHandle(Window *pParent, 
										WindowHandle hWindow) = 0;

			virtual void Detach() = 0;

			//
			// Notify controls when they are auto-resized
			//
			virtual void OnControlResizing() = 0;
			virtual void OnControlResize() = 0;

			//
			// Co-ordinate functions
			//
			virtual void ClientToWindow(Window *pWindow, 
										Point* pPoints, 
										uint cPoints) = 0;

			//
			// Redraw functions
			//
			virtual void ForceRedraw(const Rect* pRect) = 0;

			// Full-screen support
			virtual void SetWindowMode(TWindowMode Mode) = 0;
			
		protected:
			// Link back to the platform independent Window object.
			Window *m_pWindow;
	};
};

#endif // !vgui_WindowImp_h


