//
// vgui.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_h
#define vgui_h

//
// vGUI is a client of vOS
//

#include "vOS\vOS.h"
#include "vOS\ErrorManager.h"

// Make some common vgui types available
using vos::Error;

//
// Set vGui build type.
//

#if defined VOS_MSWINDOWS
// Set basic vGui build as Microsoft Windows.
#define VGUI_MSWINDOWS	(1)

#ifdef VOS_WIN32
// The Windows flavour is Win32
#define VGUI_WIN32		(1)

// Set up callback type
#define VGUI_OSCALLBACK STDAPICALLTYPE
#endif

#include "Win32\Win32_Types.h"

#elif defined VOS_MACOS
#define VGUI_MACOS		(1)

#include "MacOS_Types.h"

#endif



// Asserts

#include "Assert.h"

namespace vgui
{

// Endian flag
#ifdef VOS_LITTLE_ENDIAN
#define VGUI_LITTLE_ENDIAN (1)
#endif

	//
	//
	// Abstract factory for vGui components
	//

	// Platform independent classes
	class Window;
	class Dialog;
	class EditBox;

	// Implementation classes
	class ApplicationImp;

	class WindowImp;
	class DialogImp;
	class EditBoxImp;
	class CheckBoxImp;
	class RadioButtonImp;
	class DropDownListImp;
	class ListBoxImp;
	class DateTimeBoxImp;
	class ButtonImp;
	class SliderImp;
	class TabControlImp;
	class DialogControlImp;
	class ImageButtonImp;
	class ProgressBarImp;
	class BrowseDialogImp;
	class PopupMenuButtonImp;
	
	class MenuImp;

	class GCImp;
	class RedrawGCImp;
	class FontImp;

	class vGuiFactory
	{
		public:
			// Virtual Constructors

			//
			// Different types of application...
			//
			ApplicationImp	*MakeApplication();			// Simple app
			ApplicationImp	*MakeApplicationSDI();		// SDI app
			ApplicationImp	*MakeApplicationMDI();		// MDI app

			WindowImp			*MakeWindow();
			DialogImp			*MakeDialog();
			EditBoxImp			*MakeEditBox();
			CheckBoxImp			*MakeCheckBox();
			RadioButtonImp		*MakeRadioButton();
			DateTimeBoxImp		*MakeDateTimeBox();
			DropDownListImp		*MakeDropDownList();
			ListBoxImp			*MakeListBox();
			ButtonImp			*MakeButton();
			SliderImp			*MakeSlider();
			TabControlImp		*MakeTabControl();
			DialogControlImp	*MakeDialogControl();
			ImageButtonImp		*MakeImageButton();
			ProgressBarImp		*MakeProgressBar();
			BrowseDialogImp		*MakeBrowseDialog();
			PopupMenuButtonImp	*MakePopupMenuButton();

			MenuImp				*MakeMenu();

			GCImp			*MakeGC();
			RedrawGCImp		*MakeRedrawGC();
			FontImp			*MakeFont();
	};

	vGuiFactory& TheFactory();

	// Type for passing around typeless 32-bit values to/from
	// controls.
	typedef void* UserData;
};

#endif // !vgui_h
