//
// Win32_BrowseDialogImp.cpp - custom dialog for browsing for folders, printers, or computers.
//

#include "StdHdr.h"

#include "Win32_BrowseDialogImp.h"
#include "Win32_WindowImp.h"

#include "vOS\String.h"
#include "vOS\FileSpec.h"

#include "Win32_Headers.h"
#include "shlobj.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	int CALLBACK BrowseCallbackProc(HWND hwnd, 
									UINT uMsg, 
									LPARAM lParam, 
									LPARAM lpData)
	{
		Win32_BrowseDialogImp* pDialog = (Win32_BrowseDialogImp*) lpData;

		switch (uMsg)
		{
			case BFFM_SELCHANGED:
			{
				String Msg(pDialog->m_StatusText);

				// SHould we put the folder name in the status text?
				if (pDialog->GetFlags() & bdf_ShowFolderName)
				{
					// Yes, so work out what the new selection is
					LPITEMIDLIST ItemList = (LPITEMIDLIST) lParam;

					char szSelectedPath[MAX_PATH];

					// Default to the default folder.
					vos::FileSpec ThePath = pDialog->m_DefaultFolder;

					if (SHGetPathFromIDList(ItemList, szSelectedPath))
					{
						if (!pDialog->IsInWindowsFolder(szSelectedPath))
						{
							ThePath.SetFromString(szSelectedPath);

							// If required, add the leafname to the end.
							if (pDialog->GetFlags() & bdf_PreserveLeafname)
							{
								ThePath.AppendFilename(pDialog->m_Leafname);
							}
						}
					}

					Msg += ThePath.GetString();
				}

				// Set status text
				::SendMessage(hwnd, BFFM_SETSTATUSTEXT, 0, (LPARAM) Msg.c_str());

				break;
			}

			case BFFM_INITIALIZED:
			{
				// Centre the dialog, because the shell doesn't bother.
				Win32_WindowImp::CentreWindow(hwnd);
				break;
			}
		}

		// Always returns 0, as per API documentation.
		return 0;
	}

	Win32_BrowseDialogImp::Win32_BrowseDialogImp() : m_Flags(bdf_Normal),
													 m_pParent(NULL)
	{
		// Get the name of the system folder
		m_WindowsFolder.SetFromString(getenv("SYSTEMROOT"));
	}

	Win32_BrowseDialogImp::~Win32_BrowseDialogImp()
	{
	}

	void Win32_BrowseDialogImp::Initialise(BrowseDialogFlags Flags,
										   const Window* pParent)
	{
		// Remember flags.
		m_Flags = Flags;

		// Get parent window implementation object
		m_pParent = Win32_WindowImp::GetImp(pParent);
	}

	bool Win32_BrowseDialogImp::BrowseForFolder(const String& Title, 
												const String& StatusText,
												vos::FileSpec* pResult)
	{
		// Remember status line text
		m_StatusText = StatusText;

		// Remember specified path
		m_DefaultFolder = *pResult;
		m_Leafname = pResult->GetLeafname();

		// Attempt to select a folder
		char szSelectedPath[MAX_PATH];
		strcpy(szSelectedPath, pResult->GetString().c_str());

		// Create a structure to find out stuff with
		BROWSEINFO BrowseInfo;
		memset(&BrowseInfo, 0, sizeof(BrowseInfo));

		// Fill it with useful values
		if (m_pParent != NULL)
		{
			BrowseInfo.hwndOwner = m_pParent->GetHWND();
		}

		BrowseInfo.pidlRoot = NULL;
		BrowseInfo.pszDisplayName = szSelectedPath;
		BrowseInfo.lpszTitle = Title.c_str();
		BrowseInfo.ulFlags = BIF_RETURNONLYFSDIRS | BIF_STATUSTEXT;
		BrowseInfo.lpfn = BrowseCallbackProc;
		BrowseInfo.lParam = (LPARAM) this;
		BrowseInfo.iImage = 0;

		// Browse for the folder
		LPITEMIDLIST ItemList = SHBrowseForFolder(&BrowseInfo);

		// See if they pressed cancel or OK
		if (ItemList == NULL)
		{
			// No folder selected
			return false;
		}		
		else
		{
			// OK was pressed, so figure out the path they selected
			// If not, just return an empty string
			if (!SHGetPathFromIDList(ItemList, szSelectedPath))
				return false;

			// Deallocate the item list object
			LPMALLOC pMalloc = NULL;
			if (SHGetMalloc(&pMalloc) == NOERROR)
				pMalloc->Free(ItemList);
		}

		// If we get this far, then we must have found what we
		// are looking for
		if (strlen(szSelectedPath) > 0)
		{
			pResult->SetFromString(szSelectedPath);

			if (m_Flags & bdf_PreserveLeafname)
			{
				pResult->AppendFilename(m_Leafname);
			}

			return true;
		}
		else
		{
			return false;
		}
	}

	bool Win32_BrowseDialogImp::IsInWindowsFolder(const String& Folder)
	{
		String WindowsFolder = m_WindowsFolder.GetString();

		return Folder.StartsWith(WindowsFolder);
	}

};

