//
// Win32_ButtonImp.cpp - Window Implementation Interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Win32_ButtonImp.h"

#include "Win32_ApplicationImp.h"

#include "Win32_Headers.h"
#include "Win32_MessageInfo.h"

#include "..\Rect.h"

#include "vos\Errors.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

static const char szButtonClass[] = "BUTTON";

namespace vgui
{
	void Win32_ButtonImp::Attach(HWND hWnd)
	{
		// We have to check that the class name is correct.
		if (!IsWindowOfClass(hWnd, szButtonClass))
		{
			// Trying to attach to the wrong kind of control - it must be a button.
			vguiERROR();
			return;
		}

		// Ok, we allow it, so pass down to base class.
		ButtonImp::Attach(hWnd);
	}

	bool Win32_ButtonImp::Create(Window* pParent, 
								 const Rect& Position,
								 ControlID ID)
	{
		// Ask parent window to make child control
		Win32_WindowImp* pParentImp = GetImp(pParent);

		if (pParentImp != NULL)
		{
			m_hWnd = pParentImp->CreateChildControl(m_pWindow,
													szButtonClass, "",
													BS_PUSHBUTTON, 0,
													Position, 
													ID);
		}

		return (m_hWnd != NULL);
	}

	bool Win32_ButtonImp::GetState()
	{
		LRESULT State = SendMessage(BM_GETCHECK, 0, 0);

		// Translate result to cross-platform value
		return (State == BST_CHECKED);
	}

	/**************************************************************************

	>	ControlTranslation Win32_ButtonImp::TranslateControlNotification(const Win32_MessageInfo& MsgInfo,
																		 TMessageType* pMsgType,
																		 LRESULT* pResult,
																		 MessageParams* pParams)

		Author:		Tim Browse
		Date:		22/02/2001
		Inputs:		MsgInfo - details of the Win32 message
		Inputs:		See Win32_WindowImp::TranslateControlNotification().
		Outputs:	See Win32_WindowImp::TranslateControlNotification().
		Returns:	See Win32_WindowImp::TranslateControlNotification().

		Purpose:	Translate Win32 button notification messages into
					standardised vgui messages.

	**************************************************************************/

	ControlTranslation Win32_ButtonImp::TranslateControlNotification(const Win32_MessageInfo& MsgInfo,
																	 TMessageType* pMsgType,
																	 LRESULT* pResult,
																	 MessageParams* pParams)
	{
		switch (MsgInfo.m_uNotifyCode)
		{
			// Translate to vgui message
			case BN_CLICKED:	*pMsgType = mt_BN_CLICKED;	return ControlTranslation_OK;

			// Currently unhandled button control notifications
			case BN_DISABLE:
			case BN_DOUBLECLICKED:
			case BN_SETFOCUS: 
			case BN_KILLFOCUS:
			case BN_PAINT:
			case BN_PUSHED:
			case BN_UNPUSHED:
			{
				break;
			}
		}

		// Message unknown to Button
		return ControlTranslation_Unknown;
	}

};
