//
// Win32_CheckBoxImp.cpp - Window Implementation Interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Win32_CheckBoxImp.h"

#include "Win32_Headers.h"
#include "Win32_MessageInfo.h"

#include "vos\Errors.h"

namespace vgui
{
	void Win32_CheckBoxImp::Attach(HWND hWnd)
	{
		// We have to check that the class name is correct.
		if (!IsWindowOfClass(hWnd, "BUTTON"))
		{
			// Trying to attach to the wrong kind of control - it must be a button.
			vguiERROR();
			return;
		}

		// Ok, we allow it, so pass down to base class.
		CheckBoxImp::Attach(hWnd);
	}

	ControlState Win32_CheckBoxImp::GetState()
	{
		LRESULT State = SendMessage(BM_GETCHECK, 0, 0);

		// Translate result to cross-platform value
		switch (State)
		{
			case BST_UNCHECKED:		return cs_Unchecked;
			case BST_CHECKED:		return cs_Checked;
		}

		// Must be undefined (BST_INDETERMINATE) if we get here
		return cs_Undefined;
	}

	void Win32_CheckBoxImp::SetState(ControlState NewState)
	{
		// Does this have any effect?
		if (NewState == GetState())
		{
			// No, so ignore it
			return;
		}

		// Send message to set the state
		SendMessage(BM_SETCHECK, GetWin32State(NewState), 0);

		// Tell checkbox it has been changed
		GetCheckBox()->OnChanged();
	}

	bool Win32_CheckBoxImp::Create(Window* pParent, 
								   const Rect& Position,
								   ControlID ID)
	{
		COMPLAIN("UNIMPLEMENTED");

		// Ask parent window to make child control
		Win32_WindowImp* pParentImp = GetImp(pParent);

		if (pParentImp != NULL)
		{
			m_hWnd = pParentImp->CreateChildControl(m_pWindow, 
													"button", "",
													BS_CHECKBOX, 0,
													Position, 
													ID, 
													false);
		}

		return (m_hWnd != NULL);
	}
	
	ControlTranslation 
		Win32_CheckBoxImp::TranslateControlNotification(const Win32_MessageInfo& MsgInfo,
														TMessageType* pMsgType,
														LRESULT* pResult,
														MessageParams* pParams)
	{
		if (MsgInfo.m_uNotifyCode == BN_CLICKED)
		{
			// Checkbox has been clicked - notify platform independent object
			CheckBox* pCheckBox = (CheckBox*) m_pWindow;
			GetCheckBox()->OnClick();
		}

		// Defer to base class
		return CheckBoxImp::TranslateControlNotification(MsgInfo, pMsgType, pResult, pParams);
	}
};
