//
// Win32_CustomButton.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Win32_CustomButton.h"

#include "Win32_WindowClasses.h"
#include "Win32_ApplicationImp.h"
#include "Win32_Theme.h"
#include "Win32_Debug.h"

#include "..\Errors.h"

#include "vos\Trace.h"

#include <tmschema.h>

namespace vgui
{
	/**************************************************************************
	
	>	Win32_CustomButton::Win32_CustomButton()
	
		Author:		Tim Browse
		Date:		20/8/2002
	
		Purpose:	Constructor
	
	**************************************************************************/
	
	Win32_CustomButton::Win32_CustomButton() : m_Type(ImageButton_None)
	{
		// TCILB
	}

	LRESULT Win32_CustomButton::ControlWndProc(HWND hWnd, UINT message, 
											   WPARAM wParam, LPARAM lParam)
	{
		switch (message)
		{
			case WM_DRAWITEM:
			{
				OnDrawItem(hWnd, (DRAWITEMSTRUCT*) lParam);
				return TRUE;
			}
		}

		return Win32_CustomControl::ControlWndProc(hWnd, message, wParam, lParam);
	}

	/**************************************************************************
	
	>	void Win32_CustomButton::OnDrawItem(HWND hWnd, DRAWITEMSTRUCT* pDIS)
	
		Author:		Tim Browse
		Date:		20/8/2002
		Inputs:		hWnd - the control window being redrawn
					pDIS - the DRAWITEMSTRUCT that should be used to draw
						   the control
	
		Purpose:	Provide simple owner-draw processing for various types of 
					control	images.

	**************************************************************************/
	
	void Win32_CustomButton::OnDrawItem(HWND hWnd, DRAWITEMSTRUCT* pDIS)
	{
		switch (m_Type)
		{
			case ImageButton_CheckBox_Unchecked:
			case ImageButton_CheckBox_Checked:
			{
				bool bChecked = (m_Type == ImageButton_CheckBox_Checked);

				Rect rcClient;
				::GetClientRect(hWnd, (RECT*) &rcClient);
				
				HTHEME hTheme;
				if (GetThemeHandle(&hTheme))
				{
					//
					// Use XP theme to draw the checkbox button...
					//

					// First, draw the button edge
					int iButtonState =  PBS_NORMAL;
					if (pDIS->itemState & ODS_SELECTED)
						iButtonState = PBS_PRESSED;

					Win32_Theme::DrawThemeBackground(hTheme, pDIS->hDC,
													 BP_PUSHBUTTON, 
													 iButtonState,
													 (RECT*) &rcClient, 
													 (RECT*) &rcClient);

					// Now draw the checkbox
					int iCheckState =  CBS_UNCHECKEDNORMAL;
					if (bChecked)
						iCheckState = CBS_CHECKEDNORMAL;

					Win32_Theme::DrawThemeBackground(hTheme, pDIS->hDC,
													 BP_CHECKBOX, 
													 iCheckState,
													 (RECT*) &rcClient, 
													 (RECT*) &rcClient);
				}
				else
				{
					// Otherwise, use standard Windows 95 API to draw
					// the checkbox
					UINT uButtonState = DFCS_BUTTONPUSH;
					if (pDIS->itemState & ODS_SELECTED)
						uButtonState |= DFCS_PUSHED;

					::DrawFrameControl(pDIS->hDC, 
									   (RECT*) &rcClient, 
									   DFC_BUTTON, 
									   uButtonState);

					UINT uCheckState = DFCS_BUTTONCHECK;
					if (bChecked)
						uCheckState |= DFCS_CHECKED;

					// Calculate where to draw checkboxes - unless we
					// use XP themes, we assume they are always 13x13, as
					// this seems to be the received wisdom from usenet.
					// (Unlike the UxTheme API, DrawFrameControl() will scale
					// up the checkbox if you provide a bigger area to draw in,
					// which looks wrong).
					const int kCheckBoxSize = 13;

					rcClient.left += (rcClient.GetWidth() - kCheckBoxSize) / 2;
					rcClient.top  += (rcClient.GetHeight() - kCheckBoxSize) / 2;
					rcClient.SetWidth(kCheckBoxSize);
					rcClient.SetHeight(kCheckBoxSize);

					::DrawFrameControl(pDIS->hDC, 
									   (RECT*) &rcClient, 
									   DFC_BUTTON, 
									   uCheckState);
				}

				break;
			}
		}
	}

	/**************************************************************************
	
	>	void Win32_CustomButton::SetType(TImageButton Type)
	
		Author:		Tim Browse
		Date:		20/8/2002
		Inputs:		Type - the type of button to display
	
		Purpose:	Change the appearance of this custom button.
	
	**************************************************************************/
	
	void Win32_CustomButton::SetType(TImageButton Type)
	{
		m_Type = Type;

		// Invalidate the theme handle, as we may have just changed the
		// class of the control
		InvalidateTheme();

		// Ensure control is redrawn because of this change.
		if (m_hWnd != NULL)
		{
			::InvalidateRect(m_hWnd, NULL, TRUE);
		}
	}

	/**************************************************************************
	
	>	LPCWSTR Win32_CustomButton::GetThemeClass() const
	
		Author:		Tim Browse
		Date:		20/8/2002
		Returns:	Name of the theme class (wide character string)
	
		Purpose:	Get the theme 'class' for this control.  This lets the XP
					theme API know what type of control this is, so it knows
					how to behave when DrawThemeBackground() etc are called.
	
	**************************************************************************/
	
	LPCWSTR Win32_CustomButton::GetThemeClass() const
	{
		switch (m_Type)
		{
			case ImageButton_CheckBox_Unchecked:
			case ImageButton_CheckBox_Checked:
			{
				return L"BUTTON";
			}

			default:
			{
				return L"WINDOW";
			}
		}
	}
};



