//
// Win32_CustomControl.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_CustomControl_h
#define vgui_Win32_CustomControl_h

#include "..\vgui.h"

#include "..\Controls.h"

#include <uxtheme.h>

#include "Win32_ThemedObject.h"

namespace vgui
{
	class Window;

	/**************************************************************************
	
	>	class Win32_CustomControl : public Win32_ThemedObject
	
		Author:		Tim Browse
		Date:		20/8/2002
	
		Purpose:	Lightweight class for subclassing a control to change
					or customise it in some way.

					The class provides for simple handling of redraw over-ride
					via the OnRedraw() function.

					You should derive your particular class from this class,
					and provide an implementation of GetThemeClass().  You can
					then over-ride OnRedraw() for redraw customisation, or
					ControlWndProc() for complete control of message handling.
					
					See Win32_StaticControl for an example of this.

	**************************************************************************/
	
	class Win32_CustomControl : public Win32_ThemedObject
	{
		public:
			//
			// Constructor/destructor
			//
			Win32_CustomControl();
			~Win32_CustomControl();

			// Attach to a control
			virtual void Attach(HWND hControl);

			// Detach from the control
			void Detach();
			
			// Over-ride this to redraw the control
			virtual void OnRedraw(HWND hWnd, PAINTSTRUCT* pPS);

			// Over-ride this to do clever things
			virtual LRESULT ControlWndProc(HWND hWnd, UINT message, 
										   WPARAM wParam, LPARAM lParam);

			// Access window handle
			HWND GetHWND() { return m_hWnd; }

		private:
			static LRESULT CALLBACK RawControlWndProc(HWND hWnd, UINT message, 
												      WPARAM wParam, LPARAM lParam);

		protected:
			// Control's original WNDPROC
			WNDPROC m_WndProc;
	};
};

#endif // !vgui_Win32_CustomControl_h


