//
// Win32_Debug.h - debugging facilities
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_Debug_h
#define vgui_Win32_Debug_h

#include "..\vgui.h"

#include <typeinfo.h>

#include "..\Window.h"

#ifdef _DEBUG

//
// Macros to use to log messages
//
#define WIN32_LOGMESSAGE(hwnd, message, wParam, lParam) vgui::Win32_Debug::LogMessage(hwnd, message, wParam, lParam)
#define WIN32_LOGMESSAGEHANDLED(hwnd, message, lResult) vgui::Win32_Debug::LogMessageHandled(hwnd, message, lResult)

namespace vgui
{
	class Win32_WindowImp;
	
	class Win32_Debug
	{
		public:
			// Turn logging on/off
			static void EnableMessageLogging();
			static void DisableMessageLogging();

			// Control which messages to log
			static void EnableLoggingOfAllMessages();
			static void EnableLoggingByMessage(UINT Msg);
			static void EnableLoggingByMessage(UINT msgFirst, UINT msgLast);

			static void EnableLoggingByWindow(WindowHandle hWindow);
			static void EnableLoggingByWindowType(const type_info& Type);

			static void DisableLoggingByMessage(UINT Msg);
			static void DisableLoggingByMessage(UINT msgFirst, UINT msgLast);

			static void DisableLoggingByWindow(WindowHandle hWindow);
			static void DisableLoggingByWindowType(const type_info& Type);

			// Logging messages
			static void LogMessage(HWND hwnd, UINT message,
								   WPARAM wParam, LPARAM lParam);

			static void LogMessageHandled(HWND hwnd, UINT message,
										  LRESULT lResult);

		private:
			static void OutputMessageLog(HWND hwnd, UINT message,
										 WPARAM wParam, LPARAM lParam);

			static void OutputMessageHandledLog(HWND hwnd, UINT message,
											    LRESULT lResult);
			
			static bool MessageShouldBeLogged(HWND hwnd, UINT message);
			static const char* GetWindowName(Win32_WindowImp* pWindowImp);
	};
};

#else

// In release builds, these have no effect.
#define WIN32_LOGMESSAGE(hwnd, message, wParam, lParam)
#define WIN32_LOGMESSAGEHANDLED(hwnd, message, lResult)

#endif // _DEBUG

#endif // !vgui_Win32_Debug_h
