//
// Win32_DialogControlImp.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//
WindowStyle
#include "StdHdr.h"

#include "Win32_DialogControlImp.h"

#include "Win32_ApplicationImp.h"

#include "Win32_Headers.h"

#include "..\Rect.h"

#include "vos\Errors.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	void Win32_DialogControlImp::Attach(HWND hWnd)
	{
		// We have to check that the class name is correct.
		if (!IsWindowOfClass(hWnd, GetWin32App()->GetWindowClassName(wc_ChildWindow)))
		{
			// Trying to attach to the wrong kind of control - it must be a button.
			vguiERROR();
			return;
		}

		// Ok, we allow it, so pass down to base class.
		DialogControlImp::Attach(hWnd);
	}

	bool Win32_DialogControlImp::Create(Window* pParent, 
										const Rect& Position,
										ControlID ID,
										bool bTabStop)
	{
		COMPLAIN("UNIMPLEMENTED");

		// Ask parent window to make child control
		Win32_WindowImp* pParentImp = GetImp(pParent);

		if (pParentImp != NULL)
		{
			m_hWnd = pParentImp->CreateChildControl(m_pWindow, 
													"button", "",
													BS_PUSHBUTTON, 0,
													Position, 
													ID,
													bTabStop);
		}

		return (m_hWnd != NULL);
	}

	void Win32_DialogControlImp::Attach(Window *pParent,
										ControlID ID)
	{
		// Get parent's window handle, and use it to find control handle
		HWND hParent = GetHWND(pParent);
		HWND hControl = ::GetDlgItem(hParent, ID);

		// Find out if the control has the TABSTOP style set
		bool bTabStop = (::GetWindowLong(hControl, GWL_STYLE) & WS_TABSTOP) != 0;

		// NB. The existing dialog control is just used as a placeholder,
		//     so we destroy it and create our control at the same 
		//	   position and with the same ID.

		// Get the control's position
		Rect Position;
		::GetClientRect(hControl, (RECT*) &Position);

		// Convert to parent window co-ordinates
		::MapWindowPoints(hControl, hParent, (POINT*) &Position, 2);

		// If the prototype control has a 3D border, we need to adjust 
		// our rectangle because the standard Windows controls render 
		// 3D borders outside the control border.
		if (GetWindowLong(hControl, GWL_EXSTYLE) & WS_EX_CLIENTEDGE)
		{
			// Inflate rectangle using the 3D border width metrics.
			Position.Inflate(::GetSystemMetrics(SM_CXEDGE),
							 ::GetSystemMetrics(SM_CYEDGE));
		}

		// Delete the control
		::DestroyWindow(hControl);


		// Create our new control in its place.
		char* szControlClass = GetWin32App()->GetWindowClassName(wc_ChildWindow);
		Win32_WindowImp* pParentImp = GetImp(pParent);

		hControl = pParentImp->CreateChildControl(m_pWindow, 
												  szControlClass, "",
												  0, 0,
												  Position, 
												  ID, 
												  bTabStop);

		// Complain if we didn't create the control
		ASSERT(hControl != NULL);

		// Attach to the control
		Attach(hControl);

		// Set up any scroll bars
		SetScrollBars();
	}

	

};
