//
// Win32_DialogImp.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_DialogImp_h
#define vgui_Win32_DialogImp_h

#include "..\DialogImp.h"

#include <map>

namespace vgui
{
	//
	// Types to store DeferWindowPos() structures.
	//
	struct HDWPEntry
	{
		// Parent window of windows referred to in m_hDWP
		HWND m_hParent;

		// As returned by BeginDeferWindowPos()/DeferWindowPos()
		HDWP m_hDWP;
	};

	typedef std::vector<HDWPEntry> HDWPEntries;

	class Win32_StaticControl;

	class Win32_DialogImp : public DialogImp
	{
		public:
			// Constructor
			Win32_DialogImp();

			// Destructor
			~Win32_DialogImp();

		private:
			//
			// Implement DialogImp interface
			//
			ControlID DoModalDialog(const DialogResourceID DialogID,
									const Window *pParent,
									WindowPos Pos);

			virtual void DoModelessDialog(const DialogResourceID DialogID,
										  const Window *pParent,
										  WindowPos Pos,
										  TShowWindow Show);

			void EndDialog(ControlID ID);

			bool Create(const DialogResourceID DialogID,
						const Window *pParent);

			virtual void DisableAutoResizeGripper();

			void EnableDialogControl(ControlID ID, bool bEnable);

			void MoveControl(ControlID ID, int x, int y);
			void MoveControlRelative(ControlID ID, int DeltaX, int DeltaY);
			void ResizeControl(ControlID ID, int Width, int Height);
			void EnableControl(ControlID ID);
			void DisableControl(ControlID ID);
			void ShowControl(ControlID ID);
			void HideControl(ControlID ID);
			void GetControlPosition(ControlID, Rect* pPosition);
			void SetControlPosition(ControlID ID, const Rect& Position);
			void SetControlState(ControlID ID, ControlState NewState);
			ControlState GetControlState(ControlID ID);
			bool FindControlWindow(ControlID ID, Window** ppWindow);

			void LockControlUpdate();
			void UnlockControlUpdate();

			// Over-ride WindowImp interface
			virtual void Detach();

			void GetGripperPos(Rect* pGripperPos);
			
		protected:
			static Win32_DialogImp* GetImpFromHWND(HWND hWnd);

			bool FindDialogControl(ControlID ID, Win32_WindowImp** ppControl);
			
			virtual ControlTranslation TranslateControlNotification(const Win32_MessageInfo& MsgInfo,
																	TMessageType* pMsgType,
																	LRESULT* pResult,
																	MessageParams* pParams);

			void MoveWindow(HWND hCtrl, int x, int y, 
							int Width, int Height,
							BOOL bRepaint);

			int GetHWDPEntry(HWND hWindowToMove);

			virtual void Move(const Rect& NewPosition, bool bForceRedraw);

			DLGTEMPLATE* LockDialogResource(const DialogResourceID& ID);

			void CreateResizeGripper();

		protected:
			// Implementation
			static BOOL CALLBACK vGuiDialogProc(HWND hwndDlg,
												UINT uMsg,
												WPARAM wParam,
												LPARAM lParam);

		private:
			static Dialog* GetDialog(HWND hwnd);

			Dialog* GetDialog() { return static_cast<Dialog*>(m_pWindow); }

			DLGTEMPLATE* CreateEmptyTemplate();

			void GetControlArea(Rect* pControlArea);
			
		private:
			// Position to open dialog in
			WindowPos m_OpenPos;

			// Visibility of dialog (for modeless dialogs only)
			vgui::TShowWindow m_InitialDialogVisibility;

			// Modal or modeless?
			bool m_bModal;

			// Update lock semaphore
			int m_cUpdateLock;

			// Defer window pos struture
			HDWPEntries m_HDWPEntries;

			// Resize gripper for resizable dialogs
			Win32_StaticControl* m_pResizeGripper;
			bool m_bUseAutoResizeGripper;
	};
};

#endif // !vgui_Win32_DialogImp_h
