//
// Win32_DropDownListImp.h - Window Implementation Interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_DropDownListImp_h
#define vgui_Win32_DropDownListImp_h

#include "..\vgui.h"

#include "..\DropDownListImp.h"

#include "..\EditBox.h"
#include "..\HistoryList.h"

#include <list>

namespace vgui
{
	class Win32_DropDownListImp : public DropDownListImp
	{
		public:
			//
			// Constructor
			//
			Win32_DropDownListImp();

			// We veto attachments to make sure they're the right
			// type of control.
			virtual void Attach(HWND hWnd);

		public:
			virtual void Clear();
			virtual void ClearTextSelection();
			virtual void InsertTextAtCursor(const String& Text,
											EditBoxBehaviour Behaviour = eb_Normal);

			// Add and delete items

			virtual bool AddItem(const String& ItemName,
								 int* piItem,
								 UserData pUserData);

			virtual bool InsertItemAfter(int iAfterItem,
										 const String& ItemName, 
										 int* piItem,
										 UserData pUserData);

			virtual bool InsertItemBefore(int iBeforeItem,
										  const String& ItemName, 
										  int* piItem,
										  UserData pUserData);

			virtual bool DeleteItem(int iItem);

			virtual bool SetItemText(int iItem, const String& Text, int iColumn);
			virtual bool SetItemData(int iItem, UserData TheUserData);

			// Find out how many items there are in the list
			virtual int GetCount() const;

			// Find info about an item
			virtual bool GetItemText(int iItem, String* pItemName, int iColumn) const;
			virtual bool GetItemUserData(int iItem, UserData* pTheUserData) const;

			// Change currently selected item
			virtual bool SetSelectedItem(int iItem);

			// Access currently selected item
			virtual bool GetSelectedItem(int* piItem) const;

			// Find an item
			virtual bool FindItem(const String& ItemName, int* piFoundItem);

			// Sort control
			virtual void EnableSorting();
			virtual void DisableSorting();

			// Owner draw lists - refresh item metrics
			virtual void RemeasureItems();
			virtual void RemeasureItems(int NewHeight);

			// Control history behaviour
			virtual void EnableHistoryBehaviour(bool bEnable);
			virtual void CommitToHistory(const vos::String& Text);
			virtual void SetHistoryLimit(int Limit);

			// Control embedded edit box behaviour
			virtual void EnableCommitNotification(bool bEnable);
			
		protected:
			// Helper function for adding items
			bool InsertItemAt(int iInsertAt,
							  const String& ItemName, 
							  int* piItem,
							  UserData TheUserData);

			ControlTranslation TranslateControlNotification(const Win32_MessageInfo& MsgInfo,
															TMessageType* pMsgType,
															LRESULT* pResult,
															MessageParams* pParams);

			bool FindItem(const String& ItemName, 
						  int* piFoundItem,
						  int iStartFrom);

			bool OnTextCommit();

			virtual void OnControlResizing();
			virtual void OnControlResize();
			
		private:
			void TransferListToHistory();
			void TransferHistoryToList();

			void RawClear();
			int GetRawCount() const;
			bool GetRawItemText(int iItem, String* pItemName, int iColumn = 0) const;
			bool GetRawItemUserData(int iItem, UserData* pTheUserData) const;
			bool AddRawItem(const String& ItemName, 
						    int* piItem,
						    UserData TheUserData = NULL);
			
			virtual bool SetText(const String& Text);
			virtual bool GetText(String& Text);

		private:
			// Flag to control whether this control should use 'history'
			// behaviour.
			bool m_bUseHistoryBehaviour;

			// Flag to indicate if this control has an edit box.
			bool m_bHasEditBox;

			// The handle to the child edit box of a combobox (if it has one)
			HWND m_hEditBox;

			// Object to control the edit box (if we have one)
			EditBox m_EditBox;

			// History buffer
			HistoryList m_History;

			// Current contents of the edit box (if we have one)
			// NB. This is required due to the braindead combo box implementation
			vos::String m_EditBoxContents;
			bool m_bEditBoxContentsValid;
	};
};

#endif // !vgui_Win32_DropDownListImp_h


