//
// Win32\Win32_MRUFileMenu.cpp - Win32 specifics of the MRU file list.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "..\MRUFileMenu.h"

#include "vos\FileSpec.h"

#include "Win32_Headers.h"

#include <shlwapi.h>

namespace vgui
{
	typedef BOOL STDAPICALLTYPE PathCompactPathExFn(LPSTR, LPCSTR, UINT, DWORD);

	// Pick an arbitrary maximum size for a filename
	const int kFileNameSize = 42;

	//
	// This flag is true if we have tried to load the SHLWAPI DLL and failed.
	//
	static bool m_bSHLWAPI_FailedToLoad = false;

	//
	// The Path compacter function, if we have found it
	//
	static PathCompactPathExFn* s_pfnPathCompacterFn = NULL;

	static bool GetPathCompacter()
	{
		// If we already have a pointer to the function, use that.
		if (s_pfnPathCompacterFn != NULL)
			return true;

		// If we have tried to load the function from the library, and failed,
		// then return NULL as the function is not available.
		if (m_bSHLWAPI_FailedToLoad)
			return false;

		// Ok, first time through - try to load shlwapi.dll
		//
		// NB. We never call FreeLibrary on this DLL as we always want it to
		//     be available while the app is running.
		HMODULE hModule = ::LoadLibrary("shlwapi.dll");

		if (hModule == NULL)
		{
			// Unable to load the DLL, so don't use the path compact function
			m_bSHLWAPI_FailedToLoad = true;
			return false;
		}

		// Ok, we've loaded the DLL, so find the function.
		s_pfnPathCompacterFn = (PathCompactPathExFn*) ::GetProcAddress(hModule, "PathCompactPathExA");

		// Let the caller know how it went
		return (s_pfnPathCompacterFn != NULL);
	}

	void MRUFileMenu::ConvertFileSpecToMenuText(int iFile,
												const vos::FileSpec& FS, 
												vos::String *pMenuText)
	{
		// First, extract string representation of FileSpec
		vos::String Filename = FS.GetString();

		// is the Windows path compacter API available?
		if (GetPathCompacter())
		{
			char FilenameBuffer[kFileNameSize + 1];

			if ((*s_pfnPathCompacterFn)(FilenameBuffer, Filename.c_str(), kFileNameSize, 0))
			{
				// Path compacted successfully, so use it.
				Filename = FilenameBuffer;
			}
			else
			{
				// Failed to compact it, so just use full length string.
			}
		}
		else
		{
			// No compacter function available...just use full length string.
		}

		String MenuText("&");
		MenuText += String(iFile+1);
		MenuText += ' ';
		MenuText += Filename;
		*pMenuText = MenuText;
	}
}

