//
// Win32_PopupMenuButtonImp.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Win32_PopupMenuButtonImp.h"

#include "..\PopupMenuHandler.h"
#include "..\PopupMenuButton.h"
#include "..\Errors.h"

#include "Win32_ApplicationImp.h"
#include "Win32_MessageInfo.h"

namespace vgui
{
	Win32_PopupMenuButtonImp::Win32_PopupMenuButtonImp() : m_pPopupHandler(NULL)
	{
		// TCILB
	}
	
	void Win32_PopupMenuButtonImp::AttachMenu(MenuResourceID rMenu,
											  PopupMenuHandler* pPopupHandler)
	{
		HINSTANCE hInstance = GetWin32App()->GetInstance();

		// Tell the control what image to use
		SetImage(ImageButton_PopupMenu);
		
		// Install popup handler
		m_pPopupHandler = pPopupHandler;

		// And load the menu
		HMENU hMenu = ::LoadMenu(hInstance, MAKEINTRESOURCE(rMenu.GetID()));
		Menu* pMenu = GetMenu();
		pMenu->SetMenuRef(hMenu);
	}

	Menu* Win32_PopupMenuButtonImp::GetMenu()
	{
		PopupMenuButton* pMenuButton = (PopupMenuButton*) m_pWindow;
		return pMenuButton->GetMenu();
	}

	ControlTranslation 
		Win32_PopupMenuButtonImp::TranslateControlNotification(const Win32_MessageInfo& MsgInfo,
															   TMessageType* pMsgType,
															   LRESULT* pResult,
															   MessageParams* pParams)
	{
		if (MsgInfo.m_uNotifyCode == BN_CLICKED)
		{
			// Menu popup has been clicked - show the menu
			Menu* pMenu = GetMenu();

			UINT uNotifyFlags = 0;
					
			TPopupMenuAction MenuAction;

			if (m_pPopupHandler != NULL)
			{
				MenuAction = m_pPopupHandler->OnPopup(pMenu);

				if (MenuAction == PopupMenuAction_NotifyHandler)
				{
					// Popup handler does not want parent window to be sent a
					// message, so set flag to tell TrackPopupMenuEx() to
					// do this.
					uNotifyFlags = TPM_RETURNCMD|TPM_NONOTIFY;
				}
			}

			// Set up flags for popup menu
			UINT uFlags = uNotifyFlags;
			uFlags |= TPM_LEFTALIGN | TPM_TOPALIGN | TPM_RIGHTBUTTON;
			
			// Find the parent window
			HWND hParent = ::GetParent(m_hWnd);

			// Position it to the right of the button, aligned with the
			// top edge.
			RECT rcButton;
			::GetWindowRect(m_hWnd, &rcButton);
			int MenuCmd = TrackPopupMenuEx(::GetSubMenu(pMenu->GetMenuRef(), 0), 
										   uFlags,
										   rcButton.right+1, 
										   rcButton.top,
										   hParent, NULL);
							   
			// Should we notify the handler?
			if (MenuAction == PopupMenuAction_NotifyHandler)
			{
				if ((m_pPopupHandler != NULL) && (MenuCmd != 0))
				{
					m_pPopupHandler->OnCommand(MenuCmd);
				}
			}

			// All done, and we handled the message
			return ControlTranslation_Handled;
		}

		// Defer to base class
		return PopupMenuButtonImp::TranslateControlNotification(MsgInfo, pMsgType, pResult, pParams);
	}

};
