//
// Win32_ProgressBarImp.cpp - ProgressBar Implementation Interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Win32_ProgressBarImp.h"

#include "Win32_headers.h"

#include <commctrl.h>

#include "vos\Errors.h"


//
// Macro to check for valid window handle/state
//
#define ASSERT_VALID_WINDOW()							\
		if (!IsValid())									\
		{												\
			COMPLAIN("Invalid window handle used!");	\
			return;										\
		}


//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

const char szProgressBarClass[] = "msctls_progress32";

namespace vgui
{
	void Win32_ProgressBarImp::Attach(HWND hWnd)
	{
		// We have to check that the class name is correct.
		if (!IsWindowOfClass(hWnd, szProgressBarClass))
		{
			// Trying to attach to the wrong kind of control - it must be a button.
			vguiERROR();
			return;
		}

		// Ok, we allow it, so pass down to base class.
		ProgressBarImp::Attach(hWnd);
	}

	bool Win32_ProgressBarImp::Create(Window* pParent, 
									  const Rect& Position,
									  ControlID ID)
	{
		// Ask parent window to make child control
		Win32_WindowImp* pParentImp = GetImp(pParent);

		if (pParentImp != NULL)
		{
			// Create a standard Win32 progress bar
			m_hWnd = pParentImp->CreateChildControl(m_pWindow,
													szProgressBarClass, "",
													WS_BORDER, 0,
													Position, 
													ID);
		}

		return (m_hWnd != NULL);
	}


	void Win32_ProgressBarImp::SetRange(int Start, int End)
	{
		ASSERT_VALID_WINDOW();

		COMPLAIN_IF(End <= Start,
					"Illegal range in progress bar SetRange().");

		// Remember this range
		m_Start = Start;
		m_End = End;

		// We always use the full range of the Win32 progress bar control.
		SendMessage(PBM_SETRANGE, 0, MAKELPARAM(0, 65535)); 
	}

	void Win32_ProgressBarImp::SetPosition(int Position)
	{
		ASSERT_VALID_WINDOW();

		// Veto out of range values
		if ((Position < m_Start) || (Position > m_End))
		{
			COMPLAIN("Out of range progress bar value in SetPosition().");
			return;
		}

		// Translate the specified position to the Win32 range of 0-65535
		Position -= m_Start;

		// Find a value between 0.0 and 1.0 that represents this position.
		float fPos = ((float) Position) / ((float) m_End - m_Start);

		// Use this value to set the Win32 control
		Position = (int) (fPos * 65535.0);
		SendMessage(PBM_SETPOS, (WPARAM) Position, 0);
	}

};
