//
// Win32_RadioButtonImp.cpp - Window Implementation Interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Win32_RadioButtonImp.h"

#include "Win32_Headers.h"

#include "vos\Errors.h"

//
// Macro to check for valid window handle/state
//
#define ASSERT_VALID_WINDOW()							\
		if (!IsValid())									\
		{												\
			COMPLAIN("Invalid window handle used!");	\
			return;										\
		}

#define ASSERT_VALID_WINDOW_RETURN(RetVal)				\
		if (!IsValid())									\
		{												\
			COMPLAIN("Invalid window handle used!");	\
			return (RetVal);							\
		}

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vgui
{
	void Win32_RadioButtonImp::Attach(HWND hWnd)
	{
		// We have to check that the class name is correct.
		if (!IsWindowOfClass(hWnd, "BUTTON"))
		{
			// Trying to attach to the wrong kind of control - it must be a button.
			vguiERROR();
			return;
		}

		// Ok, we allow it, so pass down to base class.
		RadioButtonImp::Attach(hWnd);
	}

	ControlState Win32_RadioButtonImp::GetState()
	{
		ASSERT_VALID_WINDOW_RETURN(cs_Undefined);

		LRESULT State = SendMessage(BM_GETCHECK, 0, 0);

		// Translate result to cross-platform value
		switch (State)
		{
			case BST_UNCHECKED:		return cs_Unchecked;
			case BST_CHECKED:		return cs_Checked;
		}

		// Must be undefined (BST_INDETERMINATE) if we get here
		return cs_Undefined;
	}

	void Win32_RadioButtonImp::SetState(ControlState NewState)
	{
		ASSERT_VALID_WINDOW();

		// Send message to set the state
		SendMessage(BM_SETCHECK, GetWin32State(NewState), 0);
	}

	bool Win32_RadioButtonImp::Create(Window* pParent, 
								      const Rect& Position,
								      bool bAutoState,
								      ControlID ID)
	{
		COMPLAIN("UNIMPLEMENTED");

		// Ask parent window to make child control
		Win32_WindowImp* pParentImp = GetImp(pParent);

		if (pParentImp != NULL)
		{
			DWORD dwStyle = BS_RADIOBUTTON;
			if (bAutoState)
			{
				// Make radio button be an auto radio button
				dwStyle = BS_AUTORADIOBUTTON;
			}

			m_hWnd = pParentImp->CreateChildControl(m_pWindow,
													"button", "",
													dwStyle, 0,
													Position, 
													ID, 
													false);
		}

		return (m_hWnd != NULL);
	}
};
