//
// Win32_StaticControl.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_StaticControl_h
#define vgui_Win32_StaticControl_h

#include "Win32_CustomControl.h"

namespace vgui
{
	class Window;

	//
	// TControlImage - 
	typedef enum
	{
		StaticControlImage_None,
		StaticControlImage_ResizeGripper
	}
	TStaticControlImage;

	/**************************************************************************
	
	>	class Win32_StaticControl : public Win32_CustomControl
	
		Author:		Tim Browse
		Date:		20/8/2002
	
		Purpose:	Provide a simple control class for customising static
					controls - allows a particular type of image to be
					drawn easily in a window/dialog.

					For example, Win32_DialogImp uses this class to draw
					the resize gripper in the bottom right of resizable
					dialogs.
	
	**************************************************************************/
	
	class Win32_StaticControl : public Win32_CustomControl
	{
		public:
			// Constructor
			Win32_StaticControl();

			// Create a static control in a window
			void Create(HWND hParent,
						const Rect& Position,
						ControlID ID = NOCTL);

			// Use this to specify a common appearance
			void Display(TStaticControlImage Image);

			// Redraw the control's appearance
			void OnRedraw(HWND hWnd, PAINTSTRUCT* pPS);

		private:
			// Returns the class of this control, appropriate for
			// XP theme support.
			virtual LPCWSTR GetThemeClass() const;
			
		private:
			// What to draw in this control
			TStaticControlImage m_Image;
	};
};

#endif // !vgui_Win32_StaticControl_h


