//
// Win32_TabControlImp.h - Window Implementation Interface
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_TabControlImp_h
#define vgui_Win32_TabControlImp_h

#include "..\vgui.h"

#include "..\TabControlImp.h"

#include "Win32_TabList.h"

namespace vgui
{
	/**************************************************************************
	
	>	class Win32_TabControlImp : public TabControlImp
	
		Author:		Tim Browse
		Date:		13/7/2002
	
		Purpose:	THe Win32 implementation of a 'tabbed control'.
	
	**************************************************************************/
	
	class Win32_TabControlImp : public TabControlImp
	{
		public:
			//
			// Constructor
			//
			Win32_TabControlImp();

			// We veto attachments to make sure they're the right
			// type of control.
			virtual void Attach(HWND hWnd);

		public:
			// TabControlImp interface
			virtual bool AddTab(const DialogResourceID& TabID, 
								const vos::String& TabName);

			virtual bool SelectTab(const DialogResourceID& TabID);

			virtual DialogResourceID GetSelectedTab() const;

			virtual bool Create(Window* pParent, 
								const Rect& Position,
								ControlID ID);

			virtual bool OnMove(int NewX, int NewY);
			virtual bool OnResize(int NewWidth, int NewHeight);

		protected:
			void ShowTab(uint iTab);

			// Translating Win32 tabbed control notification messages
			virtual ControlTranslation TranslateControlNotification(const Win32_MessageInfo& MsgInfo,
																	TMessageType* pMsgType,
																	LRESULT* pResult,
																    MessageParams* pParams);

			void AdjustCurrentTabPosition();
			void AdjustTabPosition(const Win32_TabInfo* pTabInfo);
			
		private:
			// Data required for creating a tabbed control with multiple
			// modeless dialogs as tab panes.
			uint m_cTabs;
			Win32_TabList m_Tabs; 
	};
};

#endif // !vgui_Win32_TabControlImp_h


