//
// Win32_ThemedObject.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_ThemedObject_h
#define vgui_Win32_ThemedObject_h

#include "..\vgui.h"

#include "..\Controls.h"

#include <uxtheme.h>

namespace vgui
{
	class Window;

	/**************************************************************************
	
	>	class Win32_ThemedObject
	
		Author:		Tim Browse
		Date:		20/8/2002
	
		Purpose:	Lightweight class for providing basic support for using
					XP Themes.

					This is the basic class to inherit from if you want to
					use themes.  So for instance, Win32_WindowImp derives
					from this class, asn does Win32_CustomControl.

					NB. You must ensure that you set up m_hWnd to refer to
						a valid window handle, in order to use theme support.

	**************************************************************************/
	
	class Win32_ThemedObject
	{
		public:
			// Constructor/Destructor
			Win32_ThemedObject();
			virtual ~Win32_ThemedObject();

			// This is the class name passed to OpenThemeData().
			// (You can over-ride this - see TmSchema.h for class names)
			virtual LPCWSTR GetThemeClass() const;

			// Call this when the theme handle may have been invalidated
			// (e.g. the class of the control changes)
			void InvalidateTheme();

			// Rendering using themes
			void DrawCheckBox(HDC hDC, const Rect& rcCheckBox, 
							  ControlState State, bool bHighlight = false);

			void DrawButtonEdge(HDC hDC, const Rect& rcButton, 
							    ButtonState State, bool bHighlight = false);

			void DrawPopupMenuIcon(HDC hDC, const Rect& rcButton, 
								   ButtonState State = bs_Normal, 
								   bool bHighlight = false);
			
		protected:
			// Returns true if XP themes are active, and m_hTheme is a valid
			// theme handle that can be used with DrawThemeBackground() etc.
			bool UsingTheme();

			// Access to the theme handle
			bool GetThemeHandle(HTHEME* phTheme);

		protected:
			// Window handle for this object
			HWND m_hWnd;

		private:
			void FreeThemeHandle();

		private:
			// Windows XP Theme handle
			HTHEME m_hTheme;
	};
};

#endif // !vgui_Win32_ThemedObject_h


