//
// Win32_WindowInfo.h - for attaching data to Win32 windows
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vgui_Win32_WindowInfo_h
#define vgui_Win32_WindowInfo_h

#include "..\vgui.h"

namespace vgui
{
	typedef enum
	{
		// Arbitrary magic numbers
		WindowDataType_Window	= 0x239fd327,
		WindowDataType_View		= 0xec3108ab,
		WindowDataType_Control	= 0xc82ea419
	}
	TWindowDataType;

	class Window;
	class View;
	class Win32_CustomControl;

	/**************************************************************************
	
	>	class Win32_WindowInfo
	
		Author:		Tim Browse
		Date:		20/8/2002
	
		Purpose:	Attach vGUI specific information to a Win32 window.
			
					The GWL_USERDATA field is used to point to an instance
					of this class when vGUI has attached to a window.
	
					This class can be extended to hold other data should the
					need arise.
					
	**************************************************************************/
	
	class Win32_WindowInfo
	{
		public:
			// Attach/detach to a specific window
			static void Attach(HWND hWnd, Window* pWindow);
			static void Attach(HWND hWnd, View* pView);
			static void Attach(HWND hControl, Win32_CustomControl* pControl);
			static void Detach(HWND hWnd);

			// Access vGUI objects attached to a Win32 window
			static bool GetAttachedWindow(HWND hWnd, Window** ppWindow);
			static bool GetAttachedView(HWND hWnd, View** ppView);
			static bool GetAttachedControl(HWND hControl, Win32_CustomControl** ppControl);

		public:
			// Type of info stored on a window
			TWindowDataType m_Type;

			// Info for the window
			union
			{
				Window* m_pWindow;
				View* m_pView;
				Win32_CustomControl* m_pControl;
			};
	};

};

#endif // !vgui_Win32_WindowInfo_h
