//
// Win32_vGuiFactory.cpp - definition of virtual constructors for Win32
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "..\vgui.h"

#include "Win32_ApplicationImp.h"
#include "Win32_MDIApplicationImp.h"

#include "Win32_WindowImp.h"
#include "Win32_DialogImp.h"
#include "Win32_EditBoxImp.h"
#include "Win32_CheckBoxImp.h"
#include "Win32_RadioButtonImp.h"
#include "Win32_DateTimeBoxImp.h"
#include "Win32_ListBoxImp.h"
#include "Win32_DropDownListImp.h"
#include "Win32_ButtonImp.h"
#include "Win32_SliderImp.h"
#include "Win32_TabControlImp.h"
#include "Win32_DialogControlImp.h"
#include "Win32_ImageButtonImp.h"
#include "Win32_ProgressBarImp.h"
#include "Win32_BrowseDialogImp.h"
#include "Win32_PopupMenuButtonImp.h"

#include "Win32_GCImp.h"
#include "Win32_RedrawGCImp.h"
#include "Win32_FontImp.h"

#include "..\Errors.h"

namespace vgui
{

	// Virtual Constructors
	ApplicationImp *vGuiFactory::MakeApplication()
	{
		return new Win32_ApplicationImp;
	}

	ApplicationImp *vGuiFactory::MakeApplicationSDI()
	{
		COMPLAIN("MakeApplicationSDI() not implemented.");
		return new Win32_ApplicationImp;
	}

	ApplicationImp *vGuiFactory::MakeApplicationMDI()
	{
		return new Win32_MDIApplicationImp;
	}

	GCImp *vGuiFactory::MakeGC()
	{
		return new Win32_GCImp;
	}

	RedrawGCImp *vGuiFactory::MakeRedrawGC()
	{
		return new Win32_RedrawGCImp;
	}

	FontImp *vGuiFactory::MakeFont()
	{
		return new Win32_FontImp;
	}

	WindowImp *vGuiFactory::MakeWindow()
	{
		return new Win32_WindowImp();
	}

	DialogImp *vGuiFactory::MakeDialog()
	{
		return new Win32_DialogImp();
	}

	EditBoxImp *vGuiFactory::MakeEditBox()
	{
		return new Win32_EditBoxImp();
	}

	CheckBoxImp *vGuiFactory::MakeCheckBox()
	{
		return new Win32_CheckBoxImp();
	}

	RadioButtonImp *vGuiFactory::MakeRadioButton()
	{
		return new Win32_RadioButtonImp();
	}

	DateTimeBoxImp *vGuiFactory::MakeDateTimeBox()
	{
		return new Win32_DateTimeBoxImp();
	}

	ListBoxImp *vGuiFactory::MakeListBox()
	{
		return new Win32_ListBoxImp();
	}

	DropDownListImp *vGuiFactory::MakeDropDownList()
	{
		return new Win32_DropDownListImp();
	}

	ButtonImp *vGuiFactory::MakeButton()
	{
		return new Win32_ButtonImp();
	}

	SliderImp *vGuiFactory::MakeSlider()
	{
		return new Win32_SliderImp();
	}

	TabControlImp *vGuiFactory::MakeTabControl()
	{
		return new Win32_TabControlImp();
	}

	DialogControlImp *vGuiFactory::MakeDialogControl()
	{
		return new Win32_DialogControlImp();
	}

	ImageButtonImp *vGuiFactory::MakeImageButton()
	{
		return new Win32_ImageButtonImp();
	}

	ProgressBarImp *vGuiFactory::MakeProgressBar()
	{
		return new Win32_ProgressBarImp();
	}

	BrowseDialogImp *vGuiFactory::MakeBrowseDialog()
	{
		return new Win32_BrowseDialogImp();
	}

	PopupMenuButtonImp* vGuiFactory::MakePopupMenuButton()
	{
		return new Win32_PopupMenuButtonImp();
	}

	//
	// Factory singleton
	//
	vGuiFactory& TheFactory()
	{
		static vGuiFactory TheFactory;

		return TheFactory;
	}

}
